/**
 * Copyright(C) 2015-2016, Foxit Software Inc..
 * All Rights Reserved.
 *
 * http//:www.foxitsoftware.com
 *
 * The following code is copyrighted and contains proprietary information and trade secrets of Foxit Software Inc..
 * You cannot distribute any part of Foxit WebPDF Viewer to any third party or general public,
 * unless there is a separate license agreement with Foxit Software Inc. which explicitly grants you such rights.
 *
 */

/** 
 * Event triggerred to initialize local language after DOM loaded. 
 */
$(document).ready(function() {
    var optionsParams = {
        toolbarConfig: window.toolbarConfig,
        licenseKey: window.demoLicenseKey
    };
    var docViewerId = 'docViewer';
    WebPDF.ready(docViewerId, optionsParams, false).then(function(data) {
        initUser();
        bindEvents();
        openDocument();
    }, function(reason) {
        console.error(reason);
    });

    function openDocument() {
        if (!navigator.onLine) {
            return;
        }
        var openFileParams = null;
        if (getDocUri()) {
            var fileId = getUrlParam('fileId');
            if (!fileId) {
                fileId = getDocUri();
            }
            openFileParams = {
                url: getDocUri(),
                fileId: fileId
            };
        } else {
            openFileParams = {
                url: WebPDF.baseUrl + 'docs/sample/butterflies.pdf',
                fileId: WebPDF.baseUrl + 'docs/sample/butterflies.pdf'
            };
        }
        WebPDF.ViewerInstance.openFileByUri(openFileParams).catch(function(error) {
            console.log(error);
        });
    }
    function initUser() {
        WebPDF.AccountInstance.setUserAccount('Foxit WebPDF');
        WebPDF.AccountInstance.setUserId('7949678fa9231424e40142b6ea1b99b6');
        WebPDF.AccountInstance.setAccessToken('a9231424e40142b6');
        WebPDF.AccountInstance.setUserConfig(getUserConfig());
        WebPDF.ViewerInstance.setUserPermission(-1);
    }
    function bindEvents() {
        //user data 
        WebPDF.ViewerInstance.on(WebPDF.EventList.DOCUMENT_LOADED, function() {
            importUserData();
        }).on(WebPDF.EventList.USER_CONFIG_CHANGED, function(event, data) {
            if (data) {
                saveUserConfig(data);
            }
        }).on(WebPDF.EventList.DOCUMENT_SAVED, function(event, data) {
            saveUserData();
        }).on(WebPDF.EventList.DOCUMENT_PRE_OPEN, function(event, data) {
            console.log('Another document will be opened, you can do some actions like saving current document!');
        });
    }

    function getUserConfig() {
        var userConfigKey = WebPDF.AccountInstance.getUserId() + '_userConfig';
        var userConfig = window.sessionStorage.getItem(userConfigKey);
        return userConfig ? $.parseJSON(userConfig) : null;
    }
    function saveUserConfig(data){
        if (data.userConfig) {
            var userConfigKey = WebPDF.AccountInstance.getUserId() + '_userConfig';
            window.sessionStorage.setItem(userConfigKey, JSON.stringify(data.userConfig).toString());
        }
    }
    function saveUserData() {
        var exportAnnotAsync = WebPDF.ViewerInstance.exportAnnotsToJson();
        var exportInkSignAsync = WebPDF.ViewerInstance.exportInkSigntoJson();

        Promise.all([exportAnnotAsync, exportInkSignAsync]).then(function(results) {
            var annotsJson = results[0];
            var inkSignJson = results[1];
            if (annotsJson) {
                window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userAnnotData', JSON.stringify(annotsJson).toString());
            }
            if (inkSignJson) {
                window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userInkSignData', JSON.stringify(inkSignJson).toString());
            }
            WebPDF.ViewerInstance.setModifyState(false);
        });

        var formJson = WebPDF.ViewerInstance.exportFormToJson();
        if (formJson) {
            window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userFormData', JSON.stringify(formJson).toString());
        }
    }
    function importUserData() {
        var curFileId = WebPDF.ViewerInstance.getFileID();
        if (curFileId) {
            var userAnnotKey = curFileId + '_userAnnotData';
            var annotData = window.sessionStorage.getItem(userAnnotKey);
            if (annotData) {
                WebPDF.ViewerInstance.importAnnotsFromJson($.parseJSON(annotData));
            }
            var userInkSignKey = curFileId + '_userInkSignData';
            var inkSignData = window.sessionStorage.getItem(userInkSignKey);
            if (inkSignData) {
                WebPDF.ViewerInstance.importInkSignFromJson($.parseJSON(inkSignData));
            }
            var formKey = curFileId + '_userFormData';
            var formData = window.sessionStorage.getItem(formKey);
            if (formData) {
                WebPDF.ViewerInstance.importFormFromJson($.parseJSON(formData));
            }
        }
    }

});