/**
 * Copyright(C) 2015-2016, Foxit Software Inc..
 * All Rights Reserved.
 *
 * http//:www.foxitsoftware.com
 *
 * The following code is copyrighted and contains proprietary information and trade secrets of Foxit Software Inc..
 * You cannot distribute any part of Foxit WebPDF Viewer to any third party or general public,
 * unless there is a separate license agreement with Foxit Software Inc. which explicitly grants you such rights.
 *
 */

var ViewToolBar = (function() {

	var TABS_MIN_WIDTH = 435;
	function ViewToolBar(options) {
		this.options = options;
		this.bFullScreen = false;
		this.ieFullScreen = false;
		this.mode;
		this.tipTime = null;
		this.showFuncionlist = false;
		var fitWidth = i18n.t("ZoomLevel.FitWidth");
		var fitPage = i18n.t('ZoomLevel.FitPage');
		this.zoomFitWidth = fitWidth ? fitWidth : WebPDF.ZOOM_FIT_WIDTH;
		this.zoomFitPage = fitPage ? fitPage : WebPDF.ZOOM_FIT_PAGE;
		this.$stamList = $('#' + WebPDF.Config.stampListId);
		var _acldata;
		var _self = this;
		this.bottomToolbarTimer = null;

		this.operations = {
			savePDF: function(){
				//sample codes
				var exportAnnotAsync = WebPDF.ViewerInstance.exportAnnotsToJson();
				var exportInkSignAsync = WebPDF.ViewerInstance.exportInkSigntoJson();

				Promise.all([exportAnnotAsync, exportInkSignAsync]).then(function (results) {
					var annotsJson = results[0];
					var inkSignJson = results[1];
					if (annotsJson) {
						window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userAnnotData', JSON.stringify(annotsJson).toString());
					}
					if (inkSignJson) {
						window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userInkSignData', JSON.stringify(inkSignJson).toString());
					}
					WebPDF.ViewerInstance.setModifyState(false);
				});

				var formJson = WebPDF.ViewerInstance.exportFormToJson();
				if (formJson) {
					window.sessionStorage.setItem(WebPDF.ViewerInstance.getFileID() + '_userFormData', JSON.stringify(formJson).toString());
				}
			}
		};

		this.main = {
			id: 'main',
			onClick: function() {
				$('#' + this.id).off('click').click(function(event) {
					_self._hideAllList();
					_self._hideRibbonTabs(event);
				});
			}
		};
		this.btnImageAnnot = {
			id: "btnImageAnnot",
			onClick: function(){
				$("#selectImageCtrl").off("change").change(function changeEventHandler(event){
					if (WebPDF.Environment.ie8OrLower || WebPDF.Environment.ie9Compact) {
						WebPDF.alert(null, null, i18n.t("Compatible.IE9orLower"));
						return;
					}
					_self._hideAllList();
					var file = getFileFromEventEntity(event);
					resetImageSelector($(this), changeEventHandler);
					WebPDF.ImageAnnotPlugin.setCurrentImageFile(file);
				});
				function getFileFromEventEntity(e){
					var file = e.target.files ? e.target.files[0] : null;
					if (!file && e.dataTransfer && e.dataTransfer.files.length > 0)
						file = e.dataTransfer.files[0]
					return file;
				}
				function resetImageSelector($inputElm, changeEventHandler){
					if (WebPDF.Environment.ie) {
						var $cloned = $inputElm.clone();
						$cloned.change(changeEventHandler);
						$inputElm.replaceWith($cloned);
					} else {
						$inputElm.val('');
					}
				}
			},
			onStateChange: function(enable, visible){
				commonStatusChange(this, enable, visible);
				$("#selectImageCtrl").prop('disabled', !enable);
			},
			onSelectStateChange: function (options) {
				var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_IMAGE){
                    selected = true;
                }
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnDistance = {
			id: 'btnDistance',
			onClick: function(){
				$('#' + this.id).off('click').click(function(){
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_DISTANCE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_DISTANCE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnOpenOnline = {
			id: 'btnOpenOnline',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					_showOpenOnlineUrlDialog();
				});
			}
		};

		this.btnSave = {
			id: 'btnSaveToDatabase',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//just sample code(save to session storage)
					_self.operations.savePDF();
				});
			},
			onStateChange: function(enable, visible) {
				if (enable == true) {
					visible = true;
				}
				var $btnElement = $('#' + this.id);
				if (visible) {
					if (enable) {
						$btnElement.removeClass("disabled");
						this.onClick();
					} else {
						$btnElement.addClass("disabled");
						$btnElement.off('click');
					}
					$btnElement.parent().show();
				} else {
					$btnElement.off('click');
					$btnElement.addClass('disabled');
				}
			}
		};
		this.menuBtnSave = {
			id: 'btnMenuSave',
			onClick: function(){
				$('#' + this.id).off('click').click(function () {
					_self.operations.savePDF();
					_self.changeRbTab('home', 'file');
				});
			},
			onStateChange: function(enable, visible){
				commonStatusChange(this, enable, visible);
			}
		};
		this.btnPrint = {
			id: 'btnPrint',
			onClick: function() {
				$('#' + this.id).off('click.print').on('click.print', function() {
					_self.changeRbTab('home', 'file');
					WebPDF.ViewerInstance.print();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};
		
		this.btnTextSelectToolList = {
			id: 'btnTextSelectToolList, #btnTextSelectToolList2, #btnTextSelectToolList3, #btnTextSelectToolList4, #btnTextSelectToolList5, #btnTextSelectToolList6',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var toolid = $(this).data('id');
					$('#' + toolid).trigger('click');
				});
			},
			onStateChange: function(enable, visible, uiOption) {
				commonStatusListChange(this, enable, visible);
				if (uiOption) {
					changeBtnUI(this.id, uiOption);
				}
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_SELECTTEXT || options.newToolName == WebPDF.Tools.TOOL_NAME_SELANNOT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			},
			enableAnnotSelectTool: function(enable) {
				if (enable) {
					$('#' + _self.btnAnnotSelectTool.id).removeClass('disabled');
					//$('#' + _self.btnTextSelectToolList.id).removeClass('disabled');
				} else {
					$('#' + _self.btnAnnotSelectTool.id).addClass('disabled');
				}
			}
		};
		this.btnCommentToolList = {
			id: 'btnCommentToolList',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var toolid = $(this).data('id');
					$('#' + toolid).trigger('click');
				});
			},
			onStateChange: function(enable, visible, uiOption) {
				commonStatusListChange(this, enable, visible);
				if (uiOption) {
					changeBtnUI(this.id, uiOption);
				}
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnFreeTextToolList = {
			id: 'btnFreeTextToolList',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var toolid = $(this).data('id');
					$('#' + toolid).trigger('click');
				});
			},
			onStateChange: function(enable, visible, uiOption) {
				commonStatusListChange(this, enable, visible);
				if (uiOption) {
					changeBtnUI(this.id, uiOption);
				}
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnDrawingToolList = {
			id: 'btnDrawingToolList',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var toolid = $(this).data('id');
					$('#' + toolid).trigger('click');
				});
			},
			onStateChange: function(enable, visible, uiOption) {
				commonStatusListChange(this, enable, visible);
				if (uiOption) {
					changeBtnUI(this.id, uiOption);
				}
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnZoomToolList = {
			id: 'btnZoomToolList,#btnZoomToolList1,#btnZoomToolList2,#btnZoomToolList3,#btnZoomToolList4, #btnZoomToolList6',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var toolid = $(this).data('id');
					$('#' + toolid).trigger('click');
				});
			},
			onStateChange: function(enable, visible, uiOption) {
				commonStatusListChange(this, enable, visible);
				if (uiOption) {
					//changeBtnUI(this.id, uiOption);
					var $ele = $('#' + this.id);
					$ele.data('id', uiOption.id);
					$ele.children('i').attr('class', uiOption.className);
					$ele.children().children('i').attr('class', uiOption.className);
					$ele.data('tipdesc', uiOption.tipdesc);
					$ele.data('tiptit', uiOption.tiptit);
				}
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_ROTATE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnGotoPrevPage = {
			id: 'btnGotoPrevPage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.gotoPrevPage();
					$("#pageSelectBox").hide();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange1(this, enable);
			}
		};
		this.btnGotoNextPage = {
			id: 'btnGotoNextPage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.gotoNextPage();
					$("#pageSelectBox").hide();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange1(this, enable);
			}
		};
		this.btnGotoPrevView = {
			id: 'btnGotoPrevView',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.gotoPrevView();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange1(this, enable);
			}
		};
		this.btnGotoNextView = {
			id: 'btnGotoNextView',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.gotoNextView();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange1(this, enable);
			}
		};
		this.btnZoom = {
			id: 'btnZoom',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					var val = parseFloat($(this).data('zoom'));
					if (val) {
						val /= 100;
						WebPDF.ViewerInstance.zoomTo(val);
					}
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange1(this, enable);
			}
		};
		this.btnZoomOut = {
			id: 'btnZoomOut, #btnZoomOut2, #btnZoomOut3, #btnZoomOut4, #btnZoomOut5, #btnZoomOut6, #btnZoomOut7',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					me.id = this.id;
					if(this.id !== "btnZoomOut" && this.id !== "btnZoomOut6") {

						changeTargetUI(me, this, _self.btnZoomToolList);
					}
					WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_OUT);
				});
			},
			onStateChange: function(enable, visible) {
				this.id = "btnZoomOut, #btnZoomOut2, #btnZoomOut3, #btnZoomOut4, #btnZoomOut5, #btnZoomOut6, #btnZoomOut7";
				commonStatusChange1(this, enable);
			}
		};
		this.btnZoomIn = {
			id: 'btnZoomIn, #btnZoomIn21, #btnZoomIn31, #btnZoomIn41, #btnZoomIn51, #btnZoomIn6, #btnZoomIn7',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					me.id = this.id;
					if(this.id !== "btnZoomIn" && this.id !== "btnZoomIn6") {

						changeTargetUI(me, this, _self.btnZoomToolList);
					}
					WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_IN);
				});
			},
			onStateChange: function(enable, visible) {
				this.id = "btnZoomIn, #btnZoomIn21, #btnZoomIn31, #btnZoomIn41, #btnZoomIn51, #btnZoomIn6, #btnZoomIn7";
				commonStatusChange1(this, enable);
			}
		};
		this.btnFitPage = {
			id: 'btnFitPage2, #btnFitPage3, #btnFitPage4, #btnFitPage5, #btnFitPage6',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_FIT_PAGE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnFitWidth = {
			id: 'btnFitWidth2, #btnFitWidth3, #btnFitWidth4, #btnFitWidth5, #btnFitWidth6',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_FIT_WIDTH);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};

		this.btnPasswordProtect = {
			id: 'btnProtectTool',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					if(WebPDF.protect){
						//convert.beforeToolsConversion().then(function(fileInfo){
							WebPDF.protect.showDlg();
						//}, function(){});
					}
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(selected) {
				//commonSelectStatusChange(this.id, selected);
			}
		};
		
		this.btnSinglePage = {
			id: 'btnSinglePage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.setLayoutShowMode(WebPDF.PDFView.RD_BRMODE_SINGLE_PAGE);
				});
			},
			onStateChange: function(enable, visible) {

			},
			onSelectStateChange: function(selected) {
				if(selected.newToolName){
					return;
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnContinuousPage = {
			id: 'btnContinuousPage',
			onClick: function() {
				$('#' + this.id).off('click').on('click', function() {
					if ($(this).hasClass("disabled")) {
						return false;
					}
					WebPDF.ViewerInstance.setLayoutShowMode(WebPDF.PDFView.RD_BRMODE_CONTINUOUS);
				});
			},
			onStateChange: function(enable, visible) {

			},
			onSelectStateChange: function(selected) {
				if(selected.newToolName){
					return;
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnHandTool = {
			id: 'btnHandTool, #btnHandTool2, #btnHandTool3, #btnHandTool4, #btnHandTool5, #btnHandTool6',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_HAND);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {

                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_HAND){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnTextSelectTool = {
			id: 'btnTextSelectTool, #btnTextSelectTool2, #btnTextSelectTool3, #btnTextSelectTool4, #btnTextSelectTool5',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_SELECTTEXT);
					changeTargetUI(me, this, _self.btnTextSelectToolList);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
				if (enable) {
					$('#btnTextSelectTool b').removeClass('disabled')
						.addClass('fwr-toolbar-textselect').removeClass('fwr-toolbar-textselect-static');
					$('#btnTextSelectToolList').removeClass('disabled');
				} else {
					$('#btnTextSelectToolList').addClass('disabled');
					$('#btnTextSelectTool b').addClass('disabled').removeClass('fwr-toolbar-textselect')
						.addClass('fwr-toolbar-textselect-static');
				}
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_SELECTTEXT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnAnnotSelectTool = {
			id: 'btnAnnotSelectTool, #btnAnnotSelectTool2, #btnAnnotSelectTool3, #btnAnnotSelectTool4, #btnAnnotSelectTool5',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					if($('#'+me.id).hasClass('disabled')){return}
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_SELANNOT);
					changeTargetUI(me, this, _self.btnTextSelectToolList);
				});

			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_SELANNOT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnHighLightAnnotTool = {
			id: 'btnHighLightAnnotTool, #btnHighLightAnnotTool2',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_HIGHLIGHT);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_HIGHLIGHT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
				if(selected) {
					$(".fwr-annot-highlight-parent").css("z-index",4);
				} else {
					$(".fwr-annot-highlight-parent").css("z-index","");
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnUnderlineAnnotTool = {
			id: 'btnUnderlineAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_UNDERLINE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_UNDERLINE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
				if(selected) {
					$(".fwr-annot-underline-parent").css("z-index",4);
				} else {
					$(".fwr-annot-underline-parent").css("z-index","");
				}
			}
		};
		this.btnStrikeOutAnnotTool = {
			id: 'btnStrikeOutAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_STRIKEOUT);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {

                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_STRIKEOUT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
				if(selected) {
					$(".fwr-annot-strikeout-parent").css("z-index",4);
				} else {
					$(".fwr-annot-strikeout-parent").css("z-index","");
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnSquigglyAnnotTool = {
			id: 'btnSquigglyAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_SQUIGGLY);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_SQUIGGLY){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
				if(selected) {
					$(".fwr-annot-squiggly-parent").css("z-index",4);
				} else {
					$(".fwr-annot-squiggly-parent").css("z-index","");
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnReplaceAnnotTool = {
			id: 'btnReplaceAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','toolbar','annot_squiggly');
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_REPLACE);
					changeTargetUI(me, this, _self.btnCommentToolList);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
				var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_REPLACE){
                    selected = true;
                }
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnInsertAnnotTool = {
			id: 'btnInsertAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','toolbar','annot_squiggly');
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_CARET);
					changeTargetUI(me, this, _self.btnCommentToolList);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
				var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_CARET){
                    selected = true;
                }
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnTypeWriterAnnotTool = {
			id: 'btnTypeWriterAnnotTool, #btnTypeWriterAnnotTool2',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_TYPERWRITER);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_TYPERWRITER){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnTextboxAnnotTool = {
			id: 'btnTextboxAnnotTool',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_TEXTBOX);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_TEXTBOX){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};

		this.btnEditTextTool = {
			id: 'btnEditText',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','PhantomPDF Online Web','Edit Text Object','Edit Text Object');
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_PAGETEXT);
                    ////TODO
                    $("#btnAddText").removeClass("selected");
                    $("#btnEditText").addClass("selected");
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
				var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_PAGETEXT){
                    selected = true;
                }
				commonSelectStatusChange(this.id, selected);
			}
		};

		this.btnAddTextTool = {
			id: 'btnAddText',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','PhantomPDF Online Web','Add Text','Add Text');
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_PAGETEXT);
					var toolbar = WebPDF.ViewerInstance.getToolHandlerByName(WebPDF.Tools.TOOL_NAME_PAGETEXT);
					toolbar.activeAddText();
                    //TODO
                    $("#btnEditText").removeClass("selected");
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
			}
		};

		this.btnCalloutAnnotTool = {
			id: 'btnCalloutAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_CALLOUT);
				});

			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_CALLOUT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnPencilAnnotTool = {
			id: 'btnPencilAnnotTool',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_INKANNOT);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_INKANNOT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnTextAnnotTool = {
			id: 'btnTextAnnotTool',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
                    WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_TEXTANNOT);
                });
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_TEXTANNOT){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnRectangleAnnotTool = {
			id: 'btnRectangleAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_SQUARE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_SQUARE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnCircleAnnotTool = {
			id: 'btnCircleAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_CIRCLE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_CIRCLE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnPolygonAnnotTool = {
			id: 'btnPolygonAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_POLYGON);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_POLYGON){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnPolyLineAnnotTool = {
			id: 'btnPolyLineAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_POLYLINE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_POLYLINE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnLineAnnotTool = {
			id: 'btnLineAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_LINE);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_LINE){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnArrowAnnotTool = {
			id: 'btnArrowAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_LINEARROW);
				});

			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_LINEARROW){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnCloudAnnotTool = {
			id: 'btnCloudAnnotTool',
			onClick: function() {
				var me = this;

				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_DRAWING_CLOUD);
				});

			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_DRAWING_CLOUD){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
		this.btnExportFDF = {
			id: 'btnExportFDF',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.exportAnnotsToFDF();
					return false;
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};
		this.btnExportXFDF = {
			id: 'btnExportXFDF',
			onClick: function() {
				if(WebPDF.Environment.ie8OrLower || WebPDF.Environment.ie9Compact){return}
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.exportAnnotsToXFDF();
					return false;
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};
		this.btnExport = {
			id: 'btnExport',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					if ($(this).hasClass('disabled')){
						return false;
					} else {
						$(this).find('.fwr-rb-toolbar-arrow').click();
						return false;
					}
				});
				
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			}
		};
		this.btnComments = {
			id: 'btnComments',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					$(this).parent().children("ul").show();
					// resetDropPosition($(this).parent().children("ul"));
					$(this).parent().children("span").hide();
					_self.showFuncionlist = true;
					$('.fwr-popup-annot-focus').removeClass('fwr-popup-annot-focus');
					return false;
				});
			},
			onStateChange: function(enable, visible) {
				if (enable) {
					visible = true;
				}
				if (visible) {
					if (enable) {
						$('#' + this.id).removeClass("disabled");
						$('#' + this.id).siblings("p").removeClass("disabled");
					} else {
						$('#' + this.id).addClass("disabled");
						$('#' + this.id).siblings("p").addClass("disabled");
						$('#' + this.id).off("click");
					}
					$('#' + this.id).parent().show();
				} else {
					$('#' + this.id).addClass("disabled");
					$('#' + this.id).siblings("p").addClass("disabled");
					$('#' + this.id).off("click");
					$('#' + this.id).parent().hide();
				}
			}
		};
		this.btnShowAllComments = {
			id: 'btnShowAllComments',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.showAllAnnots();
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		this.btnHideAllComments = {
			id: 'btnHideAllComments',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.hideAllAnnots();
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		
		this.btnStamp = {
			id: 'btnStamp',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					if (WebPDF.Environment.ie8OrLower) {
						WebPDF.alert(null, null, i18n.t("InkSign.Ie8Tips"));
						return false;
					}
					_self._hideAllList();
					if(!_self.$stamList.children().length) {
						if(WebPDF.ViewerInstance)
							WebPDF.ViewerInstance.fire(WebPDF.EventList.STAMP_LIST_INIT,  null);
					}
					_self.$stamList.show();
					$(this).parent().children("span").hide();
					_self.showFuncionlist = true;
					$('.fwr-popup-annot-focus').removeClass('fwr-popup-annot-focus');
					return false;
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_STAMP){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
		};
        
        this.btnMark = {
            id: 'btnMark',
            onClick: function() {
                var me = this;

                $('#' + this.id).off('click').click(function() {
                    //ga('send','event','toolbar','toolbar','annot_arrow');
                    _self._hideAllList();
                    WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_MARK);
                    // changeTargetUI(me, this, _self.btnDrawingToolList);
                });

            },
            onStateChange: function(enable, visible) {
                commonStatusChange(this, enable, visible, true);
            },
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_MARK){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
        };
        this.btnMarkApply = {
            id: 'btnMarkApply',
            onClick: function() {
                var me = this;

                $('#' + this.id).off('click').click(function() {
                    //ga('send','event','toolbar','toolbar','annot_arrow');
                    _self._hideAllList();
                    WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_MARK_APPLY);
                    // changeTargetUI(me, this, _self.btnDrawingToolList);
                });

            },
            onStateChange: function(enable, visible) {
                commonStatusChange(this, enable, visible, true);
            },
            onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_MARK_APPLY){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
            }
        };

		this.btnInkSign = {
			id: 'btnInkSign',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					if (WebPDF.Environment.ie8OrLower) {
						WebPDF.alert(null, null, i18n.t("InkSign.Ie8Tips"));
						return false;
					}
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_INKSIGN);
					var inkSignPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.InkSignPluginName);
					WebPDF.ViewerInstance.fire(WebPDF.EventList.INKSIGN_CREATEPANEL, '');
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_INKSIGN){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
			}
		};
		this.btnImportFDF = {
			id: 'btnImportFDF',
			onClick: function() {},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			}
		};
		this.btnImportXFDF = {
			id: 'btnImportXFDF',
			onClick: function() {},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			}
		};
		this.btnImport = {
			id: 'btnImport',
			onClick: function() {
				$('#' + this.id).off('click').on('click', function() {
					if ($(this).hasClass('disabled')){
						return false;
					} else {
						$(this).find('.fwr-rb-toolbar-arrow').click();
						return false;
					}
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			}
		};
		this.btnImportForm = {
			id: 'btnImportForm',
			onClick: function() {
				$('#' + this.id).off('click').on('click', function() {
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
			}
		};
		this.btnExportForm = {
			id: 'btnExportForm',
			onClick: function() {
				$('#' + this.id).off('click').click(function(event) {
					if($(event.target).closest('a').hasClass('disabled')){
						return;
					}
					var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
					if (formPlugin) {
						formPlugin.exportToXML();
					}
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible, true);
				var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
				if(enable) {
					if(formPlugin) {
						formPlugin.showHighlightBar(true);
					}
				} else {
					if(formPlugin) {
						formPlugin.showHighlightBar(false);
					}
				}
			}
		};
		this.inputImportFormXML = {
			id: 'inputImportFormXML',
			onStateChange: function(enable, visible) {
				if (enable) {
					$('#' + this.id).css("display", "");
				} else {
					$('#' + this.id).css("display", "none");
				}
			}
		};
		this.fdfPath = {
			id: 'fdfPath',
			onStateChange: function(enable, visible) {
				if (enable) {
					$('#' + this.id).css("display", "");
				} else {
					$('#' + this.id).css("display", "none");
				}
			}
		};
		/*this.btnRotateSwitch = {
			id: 'btnRotateSwitch',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					_self._hideAllList();
					if (WebPDF.Environment.ie8OrLower) {
						WebPDF.alert(null, null, i18n.t("PCLng.ToolBar.Rotate.Ie8Tips"));
						return false;
					}
					$(this).parent().children("ul").show();
					resetDropPosition($(this).parent().children("ul"));
					$(this).parent().children("span").hide();
					_self.showFuncionlist = true;
					$('.fwr-popup-annot-focus').removeClass('fwr-popup-annot-focus');
					return false;
				});
			},
			onStateChange: function(enable, isVisable) {
				if (enable) {
					$('#' + this.id).removeClass("disabled");
					$('#' + this.id).siblings("p").removeClass("disabled");
				} else {
					$('#' + this.id).addClass("disabled");
					$('#' + this.id).off('click');
					$('#' + this.id).siblings('.fwr-toolbar-switch').addClass('disabled');
				}
			}
		};*/
		this.btnLeftRotate = {
			id: 'btnLeftRotate1',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.rotate(WebPDF.ROTATE_LEFT);
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		this.btnRightRotate = {
			id: 'btnRightRotate1',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					WebPDF.ViewerInstance.rotate(WebPDF.ROTATE_RIGHT);
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		this.btnExportPDF = {
			id: 'btnExportPDF',
			onClick: function() {
				$('#' + this.id).off('click.exportpdf').on('click.exportpdf', function() {
					WebPDF.ViewerInstance.exportDocument(null);
					return false;
				});
			},
			onStateChange: function(enable, visible,uiOption) {
				commonStatusChange(this, enable, visible);
				if (uiOption) {
					changeBtnUI(this.id, uiOption);
					commonSelectStatusChange(this.id, false);
				}
			}
		};

		this.btnSaveToComputer = {
			id: 'btnSaveToComputer',
			onClick: function() {
				$('#' + this.id).off('click').on('click', function() {
					//ga('send','event','PhantomPDF Online Web','save_as_computer','save_as_computer');
					$(this).addClass('current').siblings().removeClass('current');
					var index = $(this).index();
					$(this).parents('.fwr-rb-tab-file-body-tab').find('.fwr-rb-tab-file-body-tab-body li')
						.eq(index).addClass('current').siblings().removeClass('current');
					
					var readerApp = WebPDF.Tool.getReaderApp();
					var fileName = readerApp.getFileName();
					readerApp.getFileBuffer(readerApp.getFileID(), true, function(bufferArray) {
						var buffer = new Uint8Array(bufferArray);
						WebPDF.FileUtils.openFileByStream(buffer, "", fileName, true);
						WebPDF.Tool.getReaderApp().setCurrentDriverName('');
						var blob = new Blob([bufferArray], {type: 'application/zip'});
						webpdfsaveAs(blob,fileName);
					});
					return false;
				});
			},
			onStateChange: function(enable, visible,uiOption) {
			}
		};
		this.fullsceen = {
			id: 'fullsceen',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					_self._fullScreen();
					return false;
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		this.btnMoreTools = {
			id: 'btnMoreTools',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					$('.fwr-more-tools').show();
				});
			},
			onStateChange: function(enable, visible) {

			}
		};
		
		this.btnPPORotateLeft = {
			id: 'btnPPORotateLeft',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','tab_organize','organize_rotate_left');
					if(!canUse(this)){
						return;
					}
					var readerApp = WebPDF.Tool.getReaderApp();
					if(readerApp.getMainView() == null){
						return;
					}
					var ppoViewer =  readerApp.getMainView().getViewerManage().getViewer( WebPDF.VIEWETYPE.ppoViewer);
					ppoViewer.rotateSelectPages(WebPDF.PPORotate.left);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};

		this.btnPPORotateRight = {
			id: 'btnPPORotateRight',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','tab_organize','organize_rotate_right');
					if(!canUse(this)){
						return;
					}
					var readerApp = WebPDF.Tool.getReaderApp();
					if(readerApp.getMainView() == null){
						return;
					}
					var ppoViewer =  readerApp.getMainView().getViewerManage().getViewer( WebPDF.VIEWETYPE.ppoViewer);
					ppoViewer.rotateSelectPages(WebPDF.PPORotate.right);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};


		this.btnPPOBlankPage = {
			id: 'btnPPOBlankPage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','tab_organize','organize_blank_page');
					if(!canUse(this)){
						return;
					}
					var readerApp = WebPDF.Tool.getReaderApp();
					if(readerApp.getMainView() == null){
						return;
					}
					var ppoViewer =  readerApp.getMainView().getViewerManage().getViewer( WebPDF.VIEWETYPE.ppoViewer);
					ppoViewer.addBlankPage();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};


		this.btnPPOSelectPage = {
			id: 'btnPPOSelectPage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','tab_organize','organize_select_page');
					if(!canUse(this)){
						return;
					}
					var readerApp = WebPDF.Tool.getReaderApp();
					if(readerApp.getMainView() == null){
						return;
					}
					var ppoViewer =  readerApp.getMainView().getViewerManage().getViewer( WebPDF.VIEWETYPE.ppoViewer);
					ppoViewer.showSelectPageDialog();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};


		this.btnPPODeletePage = {
			id: 'btnPPODeletePage',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','tab_organize','organize_rotate_left');
					if(!canUse(this)){
						return;
					}
					var readerApp = WebPDF.Tool.getReaderApp();
					if(readerApp.getMainView() == null){
						return;
					}
					var ppoViewer =  readerApp.getMainView().getViewerManage().getViewer( WebPDF.VIEWETYPE.ppoViewer);
					ppoViewer.deleteSelectPages();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};

		this.btnOpenFile = {
			id: 'btnOpenFile',
			onClick: function() {
				$('#' + this.id).off('click').click(function() {
					$(".fwr-rb-tab-buttons li[data-tab = file]").click();
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			}
		};

		this.btnHighLightAreaAnnotTool = {
			id: 'btnHighLightAreaAnnotTool',
			onClick: function() {
				var me = this;
				$('#' + this.id).off('click').click(function() {
					//ga('send','event','toolbar','toolbar','annot_rectangle');
					_self._hideAllList();
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_COMMENT_HIGHLIGHT_AREA);
				});
			},
			onStateChange: function(enable, visible) {
				commonStatusChange(this, enable, visible);
			},
			onSelectStateChange: function(options) {
                var selected = false;
                if(options.newToolName == WebPDF.Tools.TOOL_NAME_COMMENT_HIGHLIGHT_AREA){
                    selected = true;
                }
                commonSelectStatusChange(this.id, selected);
				if(selected) {
					$(".fwr-annot-highlight-parent").css("z-index",4);
				} else {
					$(".fwr-annot-highlight-parent").css("z-index","");
				}
				commonSelectStatusChange(this.id, selected);
			}
		};
		this.commonButtons = [this.main, this.btnPrint, this.btnGotoPrevPage, this.btnGotoNextPage, this.btnGotoPrevView, this.btnGotoNextView,this.btnZoom,
			this.btnZoomOut, this.btnZoomIn,  this.btnFitPage,  this.btnFitWidth, this.btnSinglePage, this.btnContinuousPage, 
			this.btnPPORotateLeft,this.btnPPORotateRight,this.btnPPOBlankPage,this.btnPPOSelectPage,this.btnPPODeletePage,
			this.btnHandTool, this.btnTextSelectTool, this.btnLeftRotate, this.btnRightRotate, this.fullsceen, this.btnOpenFile];
		this.limitButtons = [this.btnAnnotSelectTool, this.btnHighLightAnnotTool, this.btnUnderlineAnnotTool, this.btnStrikeOutAnnotTool,
			this.btnSquigglyAnnotTool, this.btnTypeWriterAnnotTool, this.btnTextboxAnnotTool, this.btnCalloutAnnotTool, this.btnPencilAnnotTool, this.btnTextAnnotTool,
			this.btnRectangleAnnotTool, this.btnCircleAnnotTool, this.btnPolygonAnnotTool, this.btnPolyLineAnnotTool, this.btnLineAnnotTool, this.btnArrowAnnotTool, this.btnCloudAnnotTool, this.btnExportFDF,
			this.btnComments, this.btnShowAllComments, this.btnHideAllComments,
			this.btnImageAnnot, this.btnStamp, this.btnMark, this.btnMarkApply, this.btnInkSign, this.btnImportForm, this.btnImportFDF, this.btnImport, this.btnExportPDF, this.btnSaveToComputer,
			this.btnFreeTextToolList, this.btnCommentToolList, this.btnDrawingToolList, this.btnTextSelectToolList, this.btnZoomToolList, this.btnExportXFDF, this.btnExport,
			this.btnEditTextTool, this.btnAddTextTool,this.btnHighLightAreaAnnotTool, this.btnDistance, this.btnCloudAnnotTool
		];
		this.connectedButtons = [];

		this.activateCategory = function(category){
			if(category == 'Comment'){
				$('.fwr-rb-tab-buttons li[data-tab="comment"]').click();
			}else if(category == 'Connect'){
				$('.fwr-rb-tab-buttons li[data-tab="connect"]').click();
			}else if(category == 'Protect'){
				$('.fwr-rb-tab-buttons li[data-tab="protect"]').click();
			}else if(category == 'Form'){
				$('.fwr-rb-tab-buttons li[data-tab="form"]').click();
			}
		};

		this.changeRbTab = function(showTab, hideTab) {
			if (showTab) {
				$('.fwr-rb-tab-buttons li[data-tab=' + showTab + ']').click();
			}
			if (hideTab && hideTab === 'file') {
				$('.fwr-rb-tab-file-menu li').removeClass('current');
			}
		};
	}

	ViewToolBar.prototype = {
		init: function() {
			if (isIE()) {
				$("input[type='file']").attr("title", "");
			}

			_initFileOpenProc();
			
			this._bindViewEvent();

			if(WebPDF.Environment.ie){
				if(WebPDF.Environment.ie8OrLower || WebPDF.Environment.ie9Compact){
					$('#btnImportXFDF').addClass('disabled');
					$('#btnExportXFDF').addClass('disabled');
				}
			}

			//adjust hide SeniorFeature
			_initSeniorFeature();

			window.onbeforeunload = function(event) {
				var c = event || window.event;
				
				// fixed jira WEbPDF-2086/WEBPDF-2787				
				var parentElement = null;
				var activeElement = event.target.activeElement;
				if (activeElement) {
					parentElement = activeElement.parentElement;
				}
				
				if (WebPDF.Environment.ie || WebPDF.Environment.ieAtLeast11) {
					if (document.activeElement && document.activeElement.className === 'fwr-pc-header-a') {
						return;
					}
				} else if (activeElement && activeElement.className === 'fwr-pc-header-a') { //mailto
					return;
				} else if (parentElement && parentElement.className === 'decorate-icon') {
					return;
				}

				if (WebPDF.ViewerInstance.isDocModified()) {
					c.returnValue = i18n.t("OnBeforeUnload.DocModified");
					return;
				}

				//collect close data
				if (WebPDF && WebPDF.ViewerInstance) {
					WebPDF.ViewerInstance.closeFile();
				}

			};

			this._bindEvent();
			this.resize();
			var me = this;
			$(window).resize(function() {
				me.resize();
			});
			me._disableAllButton();
		},
		resize: function() {

			var windowWidth = $(window).width();
			var $tbs = $('.fwr-rb-tab-buttons');
			var $tbsLi = $('.fwr-rb-tab-buttons li');
			$tbsLi.css({
				'width': 'auto',
				'padding': '0 14px'
			});

			_addRbTitle();
			resizeTabButtons();
			this.resizeFileTab();
			this.resizeTabs();

			
			function resizeTabButtons() {

				var width = getTabButtonsWidth() + parseFloat($tbs.css('marginLeft'));
				
				if (width !== parseFloat($tbs.css('marginLeft'))) {
					if (windowWidth < TABS_MIN_WIDTH - 100) {
						$tbsLi.css('overflow', 'hidden');
					} else {
						$tbsLi.css('overflow', 'visible');
					}
					var sub = width - windowWidth;
					if (sub > 0) {
						var lisub = Math.ceil(sub / $tbsLi.size());
						setTabButtonsLiWidth(lisub);
					}
				}
			}

			function getTabButtonsWidth() {
				var lisWidth = 0;
				if($tbsLi != null) {
					for (var i = 0; i < $tbsLi.size(); i++) {
						lisWidth = lisWidth + $($tbsLi[i]).outerWidth();
					}
				}
				return lisWidth;
			}
			function setTabButtonsLiWidth(lisub){
				if($tbsLi != null) {
					for (var i = 0; i < $tbsLi.size(); i++) {
						var width = Math.floor(Math.floor($($tbsLi[i]).outerWidth()) - lisub);
						$($tbsLi[i]).css({
							'padding': '0',
							'width': width,
							'textAlign':'center' 
						});
					}
				}

			}
			
		},
		resizeFileTab: function() {
			var windowHeight = $(window).height();
			var toolbarHeight = $('.fwr-toolbar').height();
			var toolTabHeight = $('.fwr-rb-tabs').height();
			var fileTabHeight = windowHeight - (toolbarHeight - toolTabHeight);
			$('.fwr-rb-tab-file').height(fileTabHeight);
		},
		resizeTabs: function(recursionFlag) {

			
			if (!recursionFlag) {
				reset32icon($('.fwr-rb-tabs .fwr-rb-toolbar-commonli-left.ul-li20span'));
				$('.fwr-rb-tabs .fwr-rb-toolbar-group-li,.fwr-rb-tabs .pdfeditor').removeClass('ul-li20span mw35');
				$('.fwr-rb-tabs .fwr-rb-toolbar-commonli-left').removeClass('ul-li20span mw40 mw20');
			}
			var $currentLis = $('.fwr-rb-tabs .current>ul>li:visible');
			var $goupUls = $('.fwr-rb-tabs .current .pdfeditor,.fwr-rb-tabs .current .fwr-rb-toolbar-group-li:not(.ul-li20span)');
			var $commentUls = $('.fwr-rb-tabs .current .fwr-rb-toolbar-commonli-left:not(.ul-li20span)');

			var wWidth= $(window).width();
			var cLisWidth = getCurrentLisWidth();

			// 8 = .fwr-rb-tabs > ul {padding}
			if (cLisWidth + 9 < TABS_MIN_WIDTH) {
				return false;
			}

			// 8 = .fwr-rb-tabs > ul {padding}
			var sub = cLisWidth + 9 - wWidth;
			if (sub > 0 && (this.lastsub !== sub || recursionFlag == null)) {
				this.lastsub = sub;
				if ($goupUls.size() > 0) {
					
					var $currentGoupul = $goupUls.eq($goupUls.size() - 1);
						if ($currentGoupul.find('strong').size() > 0) {
							$currentGoupul.addClass('mw35');
						} 
						$currentGoupul.addClass('ul-li20span');
				} else {
					var $currentul = $commentUls.eq($commentUls.size() -1);
					if ($currentul.children('li').size() > 3) {
						$currentul.addClass('ul-li20span mw40'); 
					} else {
						$currentul.addClass('ul-li20span mw20');
					}
					set32iconTo16icon($currentul);
				}

				// console.log('sub' + sub);
				this.resizeTabs(true);
			}

			function set32iconTo16icon($currentul) {
				if ($currentul) {
					for(var i=0; i<$currentul.size(); i++) {
						var lis = $currentul.find('i');
						for (var j=0; j<lis.length; j++) {

							var className = lis[j].className;
							if (className.indexOf)
							if (className.indexOf('-32') >= 0) {
								lis.eq(i).data('icon', '32');
							}
							lis[j].className = className.replace(new RegExp('-32','gm'),'');

							var mimg = $(lis[j]).parents('li').data('mimg');
							if(mimg){
								$(lis[j]).css('background', 'url(' + mimg + ') no-repeat');
							}
						}
					}
				}
			}

			function reset32icon($currentul){
				if ($currentul) {
					for(var i=0; i<$currentul.size(); i++) {
						var lis = $currentul.find('i');
						for (var j=0; j<lis.length; j++) {
							var className = lis[j].className;
							var arrClassName = className.split(' ');
							if (className.indexOf('-32') < 0 && lis.eq(i).data('icon') === '32') {
								className = arrClassName[0] + '-32 ' + arrClassName[1] + '-32';
							}
							lis[j].className = className;

							var bimg = $(lis[j]).parents('li').data('bimg');
							if(bimg){
								$(lis[j]).css('background', 'url(' + bimg + ') no-repeat');
							}
						}
					}
				}
			}

			function getCurrentLisWidth() {
				var width = 0;
				for(var i=0; i<$currentLis.size(); i++) {
					width = width + $currentLis.eq(i).outerWidth();
				}
				return width;
			}
		},
		/**
		 * [registerConnectedButton description]
		 * @param  {[type]} config [description]
		 *                         
		 * @return {[type]}        [description]
		 */
		createConnectedButton: function(config) {
			var group = config.group;
			var tip = config.tip || '';
			var tipdesc = config.tipdesc || '';
			var text = config.text || '';


			var container = $('#toolbar_connect > ul');
			var cpdfContainer = container.find('li[data-label=connectedpdf]');
			var btnid = WebPDF.Common.unique('btnconnect-');
			var subcontainer;

			if(group && container.find('[type="'+group+'"]').length >0){
				subcontainer = container.find('[type="'+group+'"]').first();
			}else{
				subcontainer = $('<ul class="fwr-rb-toolbar-commonli-left clearfix"></ul>');
				if(group){
					subcontainer.attr('type', group);
				}
				var cli = $('<li/>');
				cli.append(subcontainer);
				cpdfContainer.after(cli);
			}
			var button = $('<li class="wm104"><a id="'+btnid+'" class="tip disabled" data-tiptit="'+tip+'" data-tipdesc="'+tipdesc+'">'+
				'<i class="fwr-rb-icons-32 fwr-rb-toolbar-cpdfplugin-32" style="background: url(' + config.bimg + ') no-repeat;"/>'+
				'<span>'+text+'</span>'+
				'</a></li>');
			button.data('bimg', config.bimg);
			button.data('mimg', config.mimg);
			subcontainer.append(button);


			this.connectedButtons.push({
				id: btnid,
				onClick: function() {
					$('#' + btnid).off('click').click(function() {
						if ($(this).is('.disabled')) {
							return;
						}
						config.onClick($(this));
					});
				},
				onStateChange: function(enable, visible) {
					//commonStatusChange(this, enable, visible);
				}
			});

			this._bindConnectedButtonsEvent();

			return btnid;
		},
		removeConnectedButton: function(btnid) {

			if(btnid){
				for(var i in this.connectedButtons){
					var item = this.connectedButtons[i];
					if(item.id = btnid){
						this.connectedButtons.splice(i, 1);
						break;
					}
				}
				var el = $('#'+btnid);
				if(el.length>0){
					if(el.parent().parent().children().length > 1){
						el.parent().remove();
					}else{
						el.parents('.fwr-rb-toolbar-commonli-left').parent().remove();
					}
				}
			}

			this._bindConnectedButtonsEvent();
		},
		/**
		 * @private
		 */
		_bindEvent: function() {
			var self = this;

			$('.fwr-rb-toolbar-awrap-right').off('hover').hover(function(){
				$(this).css('background', '#d7bae7');
				$(this).prev().css('background', '#fff');
			}, function(){
				$(this).css('background', 'none');
				$(this).prev().css('background', 'none');
			});
			$(".fwr-rb-toolbar-arrow").off('click').on('click', function() {
				if ($(this).hasClass("disabled") || $(this).parents(".tip").hasClass("disabled")) {
					return false;
				}
				self._hideAllList();

				$toolbarDropdown = $(this).parents('a').siblings('.fwr-rb-toolbar-dropdown');
				var $dropdownlist = $toolbarDropdown[0] == null ? $(this).siblings('.fwr-rb-toolbar-dropdown') :$toolbarDropdown;
				$dropdownlist.show();

				self.showFuncionlist = true;
				$('.fwr-popup-annot-focus').removeClass('fwr-popup-annot-focus');
				return false;
			});

			this.btnOpenOnline.onClick();

			//ribbon tips
			$('.fwr-rb-tab .tip,.fwr-rb-bottom-tab .bottom-tip').mouseover(function(event) {

				var tit = $(this).data('tiptit');
				var desc = $(this).data('tipdesc');
				var isBottomTool = $(this).hasClass('bottom-tip');
				if (tit && desc) {
					window.clearTimeout(self.tipShowtime);
					self.tipShowtime = window.setTimeout(function(){
						showTip(event, i18n.t(tit), i18n.t(desc), isBottomTool);
						self.tipsHidetime = window.setTimeout(function(){
							hideTip();
						}, 3000);
					}, 800);
				}
				
			});

			$('.fwr-rb-tab .tip,.fwr-rb-bottom-tab .bottom-tip').mouseleave(function(){
				hideTip();
			});

			function hideTip(){
				window.clearTimeout(self.tipsHidetime);
				window.clearTimeout(self.tipShowtime);
				$('.fwr-rb-toolbar-tip').hide();
			}

			function showTip(event, tit, desc, isBottomTool) {
				var top = event.pageY;
				var left = event.pageX;
				var $tip = $('.fwr-rb-toolbar-tip');
				$tip.children('dt').html(tit);
				$tip.children('dd').html(desc);

				var offsetTop = 0;
				if(isBottomTool) {
					offsetTop = $tip.height() + 63;
				}
				$tip.css({
					top: top - offsetTop,
					left: left
				});
				$tip.show();
				resetDropTipPosition($tip);
			}


			$('.fwr-rb-toolbar-dropdown').off('mouseleave').mouseleave(function() {
				$(this).hide();
			});

			// toolbar tab
			$('.fwr-rb-tab-buttons li').off('click').on('click', function(){

				if($(this).hasClass("subscribe-message")) {
					return;
				}

				if(WebPDF.Tool.getReaderApp().getCurToolHandler() &&
					WebPDF.ViewerInstance.getCurToolHandlerName()==='PageTextTool'){
					WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_HAND);
				}
				var tabname = $(this).data('tab');

				if ($('.fwr-rb-tabs').hasClass('temp-hide')) {
					$('.fwr-rb-tabs').addClass('absolute-show');
				}
				$(this).addClass('current').siblings().removeClass('current');
				if (tabname === 'file') {
					$('.fwr-rb-tabs>ul>li').removeClass('current');
					$('.fwr-rb-tabs').hide();
					$('.fwr-rb-tab-file').show();
					self.resizeFileTab();
					$('.fwr-rb-tab-file-menu li[data-tab = open]').click();
					$('.fwr-rb-tab-file-body-tab-header li[data-tab = open-computer]').click();
					$('#toolbar').removeClass('zindex11');
				} else {
					$('.fwr-rb-tabs').show();
					// $('#toolbar').addClass('zindex11');
					$('.fwr-rb-tab-file').hide();
					$('.fwr-rb-tabs>ul>li[data-name=tab-'+tabname+']').addClass('current').siblings().removeClass('current');
				}
				if (tabname === 'organize') {
					$(".fwr-rb-bottom-tabs").hide();
				}
				var gaName = "tab_" + tabname;

				self.resizeTabs();
				self.lastsub = 0;
				if(tabname == "organize"){
					WebPDF.ViewerInstance.changeViewer(WebPDF.VIEWETYPE.ppoViewer);
				}else{
                    if(WebPDF.ViewerInstance.getCurViewModel() !== WebPDF.VIEWETYPE.ppoViewer){
                        return;
                    }
					WebPDF.ViewerInstance.changeViewer(WebPDF.VIEWETYPE.mainViewer);
				}
			});

			//ribbon toobar hide
			$('.fwr-rb-tabs-up').off('click').click(function(){
				$(this).addClass('hide');
				$(this).parent().hide();
				$(this).parent().addClass('temp-hide');
				$('.fwr-rb-tabs-lock').removeClass('hide');
				$('.fwr-rb-tab-buttons li').removeClass('current');
				$('.fwr-rb-tabs>ul>li').removeClass('current');
				$(window).trigger('resize');
			});

			//ribbon lock toobar
			$('.fwr-rb-tabs-lock').off('click').click(function(){
				$(this).parent().removeClass('temp-hide absolute-show');
				$(this).parent().show();
				$('.fwr-rb-tabs-lock').addClass('hide');
				$('.fwr-rb-tabs-up').removeClass('hide');
				$(window).trigger('resize');
			});

			//file tab
			$('.fwr-rb-tab-file-menu li').off('click.filemenu').on('click.filemenu', function(){
				if($(this).hasClass("disabled")) {
					return;
				}
				var tabname = $(this).data('tab');
				$(this).addClass('current').siblings().removeClass('current');
				if (tabname) {
					$('.fwr-rb-tab-file-body>ul>li[data-name=tab-'+tabname+']').addClass('current').siblings().removeClass('current');
				}
			});

			// file body tab
			$('.fwr-rb-tab-file-body-tab-header').off('click', 'li').on('click', 'li',function(){
				$(this).addClass('current').siblings().removeClass('current');
				var index = $(this).index();
				$(this).parents('.fwr-rb-tab-file-body-tab').find('.fwr-rb-tab-file-body-tab-body li')
				.eq(index).addClass('current').siblings().removeClass('current');
			});

			//form input
			$('.fwr-rb-div-fileinput').off('click').click(function(){
				if (!$(this).parent().hasClass('disabled')) {
					$(this).parent().find('input').click();
				}
				return false;
			});
			$('#btnTrustManager').off('click.print').on('click.print', function() {
				//ga('send','event','PhantomPDF Online Web','trust_manager','trust_manager');
				//_self.changeRbTab('home', 'file');
				viewToolBar.changeRbTab('home', 'file');
				WebPDF.JSEngine&&WebPDF.JSEngine.showTrustManager();
			});
		},
		_bindCommonButtonsEvent: function() {
			for (var i = 0; i < this.commonButtons.length; i++) {
				var button = this.commonButtons[i];
				button.onClick();
			}
		},
		_bindLimitButtonsEvent: function() {
			for (var i = 0; i < this.limitButtons.length; i++) {
				var button = this.limitButtons[i];
				button.onClick();
			}
		},
		_bindConnectedButtonsEvent: function() {
			for (var i = 0; i < this.connectedButtons.length; i++) {
				var button = this.connectedButtons[i];
				button.onClick();
			}
		},
		_disableAllButton: function() {
            //TODO can use commonButtons and limintButtons
            this.btnSave.onStateChange(false, true);
			this.btnDistance.onStateChange(false, true);
            this.menuBtnSave.onStateChange(false, true);
            this.btnPrint.onStateChange(false, true);
			this.btnGotoPrevPage.onStateChange(false, true);
			this.btnGotoNextPage.onStateChange(false, true);
			this.btnGotoPrevView.onStateChange(false, true);
			this.btnGotoNextView.onStateChange(false, true);
            this.btnZoomOut.onStateChange(false, true);
            this.btnZoomIn.onStateChange(false, true);
			this.btnZoomToolList.onStateChange(false, true);
            this.btnPasswordProtect.onStateChange(false, true);
            this.btnHandTool.onStateChange(false, true);
            this.btnTextSelectToolList.onStateChange(false, true);
            //this.btnRotateSwitch.onStateChange(false, true);
            this.fullsceen.onStateChange(false, true);
            this.btnMoreTools.onStateChange(false, true);
            this.btnTextAnnotTool.onStateChange(false, true);
			this.btnPencilAnnotTool.onStateChange(false, true);
			this.btnZoomToolList.onStateChange(false, true);

			this.btnImportForm.onStateChange(false, true);
			this.btnExportForm.onStateChange(false, true);

            this.btnHighLightAnnotTool.onStateChange(false, true);
            this.btnUnderlineAnnotTool.onStateChange(false, true);
            this.btnStrikeOutAnnotTool.onStateChange(false, true);
            this.btnSquigglyAnnotTool.onStateChange(false, true);
            this.btnReplaceAnnotTool.onStateChange(false, true);
            this.btnInsertAnnotTool.onStateChange(false, true);
            this.btnHighLightAreaAnnotTool.onStateChange(false, true);

            this.btnTypeWriterAnnotTool.onStateChange(false, true);
            this.btnTextboxAnnotTool.onStateChange(false, true);
            this.btnCalloutAnnotTool.onStateChange(false, true);
	    	this.btnEditTextTool.onStateChange(false, true);
	    	this.btnAddTextTool.onStateChange(false, true);


            this.btnRectangleAnnotTool.onStateChange(false, true);
            this.btnCircleAnnotTool.onStateChange(false, true);
            this.btnPolygonAnnotTool.onStateChange(false, true);
            this.btnArrowAnnotTool.onStateChange(false, true);
            this.btnLineAnnotTool.onStateChange(false, true);
            this.btnPolyLineAnnotTool.onStateChange(false, true);
            this.btnCloudAnnotTool.onStateChange(false, true);

            this.btnImageAnnot.onStateChange(false, true);
            this.btnStamp.onStateChange(false, true);
            this.btnComments.onStateChange(false, true);

            this.btnImportFDF.onStateChange(false, true);
            this.btnExportFDF.onStateChange(false, true);
            this.btnImportXFDF.onStateChange(false, true);
            this.btnExportXFDF.onStateChange(false, true);
            this.btnImport.onStateChange(false, true);
            this.btnExport.onStateChange(false, true);

            this.fdfPath.onStateChange(false, true);

            this.btnInkSign.onStateChange(false, true);
            this.btnExportPDF.onStateChange(false, true);

			for(var i in this.connectedButtons){
				this.connectedButtons[i].onStateChange(false, true);
			}
			var ppoBtn = [this.btnPPORotateLeft,this.btnPPORotateRight,this.btnPPOBlankPage,this.btnPPOSelectPage,this.btnPPODeletePage];

			$.each(ppoBtn,function(index,btn){
				btn.onStateChange(false,true);
			});

            this.btnMarkApply.onStateChange(false, true);
			$('.tip.toolbar-importfile').addClass('disabled');
			$('.tip.toolbar-exportfile').addClass('disabled');

			$("#pageSelectInput").val('');
			$("#zoomSelectInput").val('');
			$("#zoomSelectInput1").val('');
		},

		/**
		 * @private
		 */
		_bindViewEvent: function() {
			var self = this;
			this.btnOpenFile.onStateChange(true, true);
			this.btnOpenFile.onClick();

			WebPDF.ViewerInstance.on(WebPDF.EventList.DOCUMENT_LOADED, function(event, data) {
				self._bindCommonButtonsEvent();
				self._bindLimitButtonsEvent();
				
				_acldata = data;

				if (data.readOnly) {
					$('.fwr-rb-title').addClass('suffix-readonly');
				} else {
					$('.fwr-rb-title').removeClass('suffix-readonly');
				}
				
				$('.tip.toolbar-importfile').removeClass('disabled');
				$('.tip.toolbar-exportfile').removeClass('disabled');

				
				var ppoBtn = [self.btnPPOBlankPage,self.btnPPOSelectPage];

				//TODO
				// has not password
				var docpermission = WebPDF.Tool.getReaderApp().getPDFDoc().getPermission()&WebPDF.Tool.getReaderApp().getUserPermission();
				var disablePasswordProtect = (docpermission == 4294967295 || docpermission == -1) && !_readerApp.getPDFDoc().hasSig();

				self._updateToolBarStatus(data.plugins, data.disablePrint, data.disableDownload, 
					data.docPermission, data.securityType,data.readOnly, data.disableOffonline,data.isShareDocument, disablePasswordProtect,
					data.disableSave);
				
				if(data.securityType == 1){
					if((_readerApp.getPDFDoc().getPermission()& 0x400)||(_readerApp.getPDFDoc().getPermission()& 0x8)){
						$.each(ppoBtn,function(index,btn){
							btn.onStateChange(true,true);
						});
					}else{
						$.each(ppoBtn,function(index,btn){
							btn.onStateChange(false,true);
						});
					}

					if(data.docPermission.isForm && _readerApp.getPDFDoc().getPermission()& 0x8){
						$('#btnExportForm').remove('disabled');
					}else{
						$('#btnExportForm').addClass('disabled');
					}
				} else {
					if(!(_readerApp.getPDFDoc().getPermission()& 0x400)){
						$.each(ppoBtn,function(index,btn){
							btn.onStateChange(false,true);
						});
					}else{
						$.each(ppoBtn,function(index,btn){
							btn.onStateChange(true,true);
						});
					}
				}

				//When open a new document need to initialized when page jump list.
				initGotoPageSelection();
				self.changePPOButtonState(false);
				//When open a new document need to initialized when page zoom list.
				self._initZoomSelection();
				self.resize();
				var count = 0;
				$(".fwr-rb-bottom-tabs").css("display","block");
				self.bottomToolbarTimer = window.setInterval(function() {
					if(count === 0) {
						$(".fwr-rb-bottom-tabs").css("display","none");
					} else {
						window.clearInterval(self.bottomToolbarTimer);
					}
					count ++;
				}, 10000);
				//add docProperties in file tab
				_createDocProperties();
				_addRbTitle();
				switch(WebPDF.ViewerInstance.getCurViewModel()){
					case  WebPDF.VIEWETYPE.ppoViewer:
                        $('.fwr-rb-tab-buttons li[data-tab=organize]').click();
                        break;
                    case  WebPDF.VIEWETYPE.redactViewer:
                        $('.fwr-rb-tab-buttons li[data-tab=protect]').click();
                        self.btnMark.onSelectStateChange( {newToolName : WebPDF.Tools.TOOL_NAME_MARK});
                        $('#' + self.btnMark.id).click();
                        break;
                }

                var readerApp = WebPDF.Tool.getReaderApp();
                if (readerApp.isOffline()) {
                	$('#fwr-textSelect-context-menu li[menuname=Menuinline-comment]').hide();

                } else {
                	$('#fwr-textSelect-context-menu li[menuname=Menuinline-comment]').show();
                }
			}).on(WebPDF.EventList.DOCUMENT_PROPERTIES_CHANGED, function(event, data) {
				var newMetadata = data.metadata;
				var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
				for(var key in newMetadata) {
					$('[metadata-key='+key+']').text(docProperties.getPropertyValue(key));
				}
			}).on(WebPDF.EventList.PAGE_TEXT_LOADED, function(event, data){

			
		       
		    }).on(WebPDF.EventList.TOOL_CHANGED, function(event, data) {
				//When switching tools need to update the state of the tool bar.
				self._updateToolsUI(data.oldToolName, data.newToolName);
			}).on(WebPDF.EventList.LAYOUTSHOWMODE_CHANGED, function(event, data) {
				//When switching tools need to update the state of the tool bar.
				self._updateShowModeUI(data.oldShowMode, data.newShowMode);
			}).on(WebPDF.EventList.DOC_MODIFY_STATE_CHANGED, function(event, isModified) {
				//Change  the state of save button if the document is modify.
				var disableSaveBtn = _acldata && _acldata.disableSave || !isModified;
				self.btnSave.onStateChange(!disableSaveBtn, true);
				self.menuBtnSave.onStateChange(!disableSaveBtn, true);
				
			}).on(WebPDF.EventList.MASK_MODIFY_STATE_CHANGED, function(event, isModified) {
                //Change  the state of save button if the document is modify.
                if (isModified) { // doc changed
                    self.btnMarkApply.onStateChange(true);
                } else {
                    self.btnMarkApply.onStateChange(false, true);
                }
            }).on(WebPDF.EventList.DOCVIEW_PAGE_CHANGED, function(event, data) {
				//If the current page is the first page the first page need to disable the goto prev page button.
				//If the current page is the last page need to disable the goto next page button.
				var pageCount = WebPDF.ViewerInstance.getPageCount();
				if (data.curIndex == 0)
					self.btnGotoPrevPage.onStateChange(false);
				else
					self.btnGotoPrevPage.onStateChange(true);

				if (data.curIndex == pageCount - 1)
					self.btnGotoNextPage.onStateChange(false);
				else
					self.btnGotoNextPage.onStateChange(true);

				var options = $("#pageSelectOption");
				var li = options.find("li");
				var liOption = li[data.curIndex];
				$(liOption).addClass('selected').siblings().removeClass('selected');
				var value = $(liOption).text();
				$("#pageSelectInput").val(value);
				
				$('#docPropertiesPageSize').html(_getPageSize());

			}).on(WebPDF.EventList.HISTORY_VIEW_CHANGE, function(event, data) {
				self.btnGotoPrevView.onStateChange(!!data.historyPrevViewCount);
				self.btnGotoNextView.onStateChange(!!data.historyNextViewCount);
			}).on(WebPDF.EventList.DOCVIEW_ZOOM_CHANGED, function(event, data) {
				var isFitWidth = WebPDF.ViewerInstance.isFitWidth();
				var isFitPage = WebPDF.ViewerInstance.isFitPage();

				var curZoom = WebPDF.ViewerInstance.getCurZoomLevel();
				var currentZoomIndex = -1;

				var zoomlevel = curZoom * 100 + "%";

				if (isFitWidth) {
					zoomlevel = self.zoomFitWidth;
				}
				if (isFitPage) {
					zoomlevel = self.zoomFitPage;
				}

				var options = $("#zoomselectoption1");
				var li = options.find("li");

				for (var i = 0; i < li.length; i++) {
					var liOption = li[i];
					var value = $(liOption).text();
					if (zoomlevel === value) {
						$(liOption).addClass('selected').siblings().removeClass('selected');
						//$("#zoomSelectInput").val(value);
						$("#zoomSelectInput1").val(value);
						break;
					}
				}

				var zoomList = WebPDF.ViewerInstance.getZoomLevels();
				for (var i = 0; i < zoomList.length; i++) {
					var zoom = zoomList[i];
					if (zoom === curZoom || (zoom === WebPDF.ZOOM_FIT_WIDTH && isFitWidth) ||
					 zoom === WebPDF.ZOOM_FIT_PAGE && isFitPage) {
						currentZoomIndex = i;
					}
				}

				if (isFitPage) {
					$('#btnContinuousPage').addClass('disabled');
					$('#btnContinuousPage b').addClass('disabled');
				} else {
					$('#btnContinuousPage').removeClass('disabled');
					$('#btnContinuousPage b').removeClass('disabled');
				}

				if (currentZoomIndex == 0)
					self.btnZoomOut.onStateChange(false);
				else
					self.btnZoomOut.onStateChange(true);  

				if (currentZoomIndex == zoomList.length - 1)
					self.btnZoomIn.onStateChange(false);
				else
					self.btnZoomIn.onStateChange(true);
			}).on(WebPDF.EventList.DOCUMENT_CLOSED, function(event, data) {
				self._disableAllButton();
			}).on(WebPDF.EventList.PPO_PAGE_SELECT_CHANGE, function(event, data) {
				self.changePPOButtonState(data.isSelect);
			}).on(WebPDF.EventList.DOCUMENT_ACL_CHANGED, function(event, data) {
				var ppoBtn = [self.btnPPOBlankPage,self.btnPPOSelectPage];
				
				if(!data.docPermission.isAnnot){
					$('.tip.toolbar-importfile').addClass('disabled');
					$('.tip.toolbar-exportfile').addClass('disabled');
				}
				if((_readerApp.getPDFDoc().getPermission()& 0x400)||(_readerApp.getPDFDoc().getPermission()& 0x8)){
					$.each(ppoBtn,function(index,btn){
						btn.onStateChange(true,true);
					});
				}else{
					$.each(ppoBtn,function(index,btn){
						btn.onStateChange(false,true);
					});
				}
				_acldata = data;

				var docpermission = WebPDF.Tool.getReaderApp().getPDFDoc().getPermission();
				var disablePasswordProtect = (docpermission == 4294967295);

				self._updateToolBarStatus(data.plugins, data.disablePrint, data.disableDownload, 
					data.docPermission, data.securityType,data.readOnly, data.disableOffonline,data.isShareDocument, disablePasswordProtect,
					data.disableSave);

				if(data.securityType == 1){
					if(data.docPermission.isForm && _readerApp.getPDFDoc().getPermission()& 0x8){
						$('#btnExportForm').remove('disabled');
					}else{
						$('#btnExportForm').addClass('disabled');
					}
				}
			})
		},
		/*
		 * @private
		 * Update the statue of tool bar, Enable or disable certain functions.
		 * @param plugins {Integer} Support plug-ins for currently open file. Currently only supports the following two plug-ins:
		 * 				WebPDF.Config.Plugins.flag.Comments
		 * 				WebPDF.Config.Plugins.flag.Signature
		 * @param readOnly{Boolean} True disable module of comment and signature, false not.	 
		 * @param disablePrint{Boolean} True disable print button, false not.
		 * @param disableDownload{Boolean} True disable download button, false not. 
		 * @param textExtract{Boolean} True enable extract text, false not.
		 * @param createForm{Boolean} True enable create form, false not.
		 */

		_updateToolBarStatus: function(plugins, disablePrint, disableDownload, 
			docPermission, securityType,readOnly, disableOffonline,shareDocument, disablePasswordProtect, disableSave) {

			//TODO
			this.btnEditTextTool.onStateChange(true);
			this.btnAddTextTool.onStateChange(true);


			this.btnHandTool.onStateChange(true);
			this.btnPasswordProtect.onStateChange(disablePasswordProtect, true);

			if (disableDownload) {
				this.btnExportPDF.onStateChange(false,true);
			}else{
				this.btnExportPDF.onStateChange(true,true);
			}

			if (!disableDownload || securityType == 1) {
				$("#btnExportPDF").parent().show();
			}

			if(disableSave){
				this.btnSave.onStateChange(false,true);
				$("#btnSaveAs").addClass('disabled');
			}else if(WebPDF.ViewerInstance.isDocModified()){
				this.btnSave.onStateChange(true,true);
				$("#btnSaveAs").removeClass('disabled');
			}

			$("#btnProperties").removeClass('disabled');

			if (disablePrint) {
				this.btnPrint.onStateChange(false,true);
			}else{
				this.btnPrint.onStateChange(true,true);
			}

			if (!disablePrint && docPermission.isPrint && securityType != 1) {
				// Print button click event
				$("#btnPrint").removeClass("disabled");
			}

			if (!disablePrint && !docPermission.isPrint) {
				this.btnPrint.onStateChange(false,true);
			}

			if(!docPermission.isModified || securityType === 1){
				this.btnEditTextTool.onStateChange(false,true);
				this.btnAddTextTool.onStateChange(false,true);
			}

			this._updateSaveStatus(plugins, docPermission);
			//support comment module
			this._updateCommentToolStatus(plugins, docPermission);
			//support comment module
			this._updateFormToolStatus(plugins, docPermission);
			//support signature module
			this._updateProtectedToolStatus(plugins, docPermission, readOnly);
		},
		/**
		 * Update the tool button state style when WebPDF change the current tool.
		 *
		 * @method _updateToolsUI
		 * @param {String} oldToolName The old tool name.
		 * @param {String} newToolName The new tool name.
		 */
		_updateToolsUI: function(oldToolName, newToolName) {
            for(var i in this.commonButtons){
                if(!$.isFunction(this.commonButtons[i].onSelectStateChange)){
                    continue;
                }
                this.commonButtons[i].onSelectStateChange({oldToolName:oldToolName,newToolName:newToolName });
            }
            for(var i in this.limitButtons){
                if(!$.isFunction(this.limitButtons[i].onSelectStateChange)){
                    continue;
                }
                this.limitButtons[i].onSelectStateChange({oldToolName:oldToolName,newToolName:newToolName });
            }
		},
        _updateProtectedToolStatus: function(plugins, docPermission,readOnly) {
            //mask
            if(readOnly || !docPermission.isModified) {
                this.btnMark.onStateChange(false, true);
            } else {
                this.btnMark.onStateChange(true);
            }
            this.btnMarkApply.onStateChange(false, true);
            //signature
			if ( plugins & WebPDF.Config.Plugins.flag.Signature) {//!WebPDF.Engine.isJR &&
				if (docPermission.isSignature) {
					if (!WebPDF.Environment.ie8OrLower) {
						this.btnInkSign.onStateChange(true);
					}
				} else {
					this.btnInkSign.onStateChange(false, true);
				}
			} else {
				this.btnInkSign.onStateChange(false, false);
			}
			if (docPermission.isModified && !readOnly) {
				this.btnPasswordProtect.onStateChange(true, true);
			} else {
				this.btnPasswordProtect.onStateChange(false, true);
			}
		},
		/**
		 * Update the tool button state style when WebPDF change the show mode.
		 *
		 * @method updateShowModeUI
		 * @param {String} oldShowMode The old show mode.
		 * @param {String} newShowMode The new show mode.
		 */
		_updateShowModeUI: function(oldShowMode, newShowMode) {
			if (newShowMode == WebPDF.PDFView.RD_BRMODE_SINGLE_PAGE) {
				this.btnSinglePage.onSelectStateChange(true);
				this.btnContinuousPage.onSelectStateChange(false);
			}

			if (newShowMode == WebPDF.PDFView.RD_BRMODE_CONTINUOUS) {
				this.btnContinuousPage.onSelectStateChange(true);
				this.btnSinglePage.onSelectStateChange(false);
			}
		},
		_updateCommentToolStatus: function(plugins, docPermission) {
			// Select text button click event
			this.btnTextSelectTool.onStateChange(true, true);
			this.btnTextSelectToolList.onStateChange(true, true);
			this.btnZoomToolList.onStateChange(true, true);
			this.btnComments.onStateChange(true);
			//support comment module
			if (!(plugins & WebPDF.Config.Plugins.flag.Comments)) {
				this.btnSave.onStateChange(false, false);
				this.btnDistance.onStateChange(false, false);
				this.btnPencilAnnotTool.onStateChange(false, false);
				this.btnTextAnnotTool.onStateChange(false, false);
				this.btnImageAnnot.onStateChange(false, false);
				this.btnStamp.onStateChange(false, false);

				this.btnHighLightAnnotTool.onStateChange(false, false);
				this.btnUnderlineAnnotTool.onStateChange(false, false);
				this.btnStrikeOutAnnotTool.onStateChange(false, false);
				this.btnSquigglyAnnotTool.onStateChange(false, false);
				this.btnReplaceAnnotTool.onStateChange(false, false);
            	this.btnInsertAnnotTool.onStateChange(false, false);
				this.btnHighLightAreaAnnotTool.onStateChange(false, false);

				this.btnTypeWriterAnnotTool.onStateChange(false, false);
				this.btnTextboxAnnotTool.onStateChange(false, false);
				this.btnCalloutAnnotTool.onStateChange(false, false);

				this.btnTextSelectToolList.enableAnnotSelectTool(false);

				//show or hide comments button
				//this.btnComments.onStateChange(false, false);
				this.btnImportFDF.onStateChange(false, false);
				this.btnExportFDF.onStateChange(false, false);
				this.btnImportXFDF.onStateChange(false, false);
				this.btnExportXFDF.onStateChange(false, false);
				this.btnImport.onStateChange(false, false);
				this.btnExport.onStateChange(false, false);

				this.fdfPath.onStateChange(false, false);

				$("#annotsToolLine").parent().hide();

				this._enableDrawingAnnots(false, false);
			} else {
				if (docPermission.isAnnot) {
					
					this.btnDistance.onStateChange(true);

					// Typewriter annotation button click event
					this.btnTypeWriterAnnotTool.onStateChange(true);
					this.btnTextboxAnnotTool.onStateChange(true);
					this.btnCalloutAnnotTool.onStateChange(true);

					// Pencil annotation button click event
					this.btnPencilAnnotTool.onStateChange(true);
					// Note annotation button click event
					this.btnTextAnnotTool.onStateChange(true);
					this.btnImageAnnot.onStateChange(true);
					// Stamp annotation button click event
					if (!WebPDF.Environment.ie8OrLower) {
						this.btnStamp.onStateChange(true);
					}
					
					// Export FDF button click event
					this.btnImportFDF.onStateChange(true);
					this.btnExportFDF.onStateChange(true);
					this.btnImportXFDF.onStateChange(true);
					this.btnExportXFDF.onStateChange(true);
					this.btnImport.onStateChange(true);
					this.btnExport.onStateChange(true);

					this.fdfPath.onStateChange(true);
					
					this.btnHighLightAnnotTool.onStateChange(true);
					this.btnUnderlineAnnotTool.onStateChange(true);
					this.btnStrikeOutAnnotTool.onStateChange(true);
					this.btnSquigglyAnnotTool.onStateChange(true);
					this.btnReplaceAnnotTool.onStateChange(true);
            		this.btnInsertAnnotTool.onStateChange(true);
					this.btnHighLightAreaAnnotTool.onStateChange(true);

					this.btnTextSelectToolList.enableAnnotSelectTool(true);
					$("#annotsToolLine").parent().show();
					this._enableDrawingAnnots(true);
				} else {

					this.btnDistance.onStateChange(false, true);
					
					this.btnTypeWriterAnnotTool.onStateChange(false, true);
					this.btnTextboxAnnotTool.onStateChange(false, true);
					this.btnCalloutAnnotTool.onStateChange(false, true);

					this.btnPencilAnnotTool.onStateChange(false, true);
					this.btnTextAnnotTool.onStateChange(false, true);
					this.btnImageAnnot.onStateChange(false, true);
					this.btnStamp.onStateChange(false, true);

					this.btnImportFDF.onStateChange(false, true);
					this.btnExportFDF.onStateChange(false, true);
					this.btnImportXFDF.onStateChange(false, true);
					this.btnExportXFDF.onStateChange(false, true);
					this.btnImport.onStateChange(false, true);
					this.btnExport.onStateChange(false, true);

					this.fdfPath.onStateChange(false, true);

					//show or hide comments button
					this.btnHighLightAnnotTool.onStateChange(false, true);
					this.btnUnderlineAnnotTool.onStateChange(false, true);
					this.btnStrikeOutAnnotTool.onStateChange(false, true);
					this.btnSquigglyAnnotTool.onStateChange(false, true);
					this.btnReplaceAnnotTool.onStateChange(false, true);
            		this.btnInsertAnnotTool.onStateChange(false, true);
					this.btnHighLightAreaAnnotTool.onStateChange(false, true);

					this.btnTextSelectToolList.enableAnnotSelectTool(false);
					$("#annotsToolLine").parent().show();

					this._enableDrawingAnnots(false, true);
				}
			}

		},
		_enableDrawingAnnots: function(enable, visible) {
			if (enable) {
				visible = true;
			}
			if (visible) {
				if (enable) {
					this.btnRectangleAnnotTool.onStateChange(true, true);
					this.btnCircleAnnotTool.onStateChange(true, true);
					this.btnPolygonAnnotTool.onStateChange(true, true);
					this.btnArrowAnnotTool.onStateChange(true, true);
					this.btnLineAnnotTool.onStateChange(true, true);
					this.btnPolyLineAnnotTool.onStateChange(true, true);
					this.btnCloudAnnotTool.onStateChange(true, true);
				} else {
					this.btnRectangleAnnotTool.onStateChange(false, true);
					this.btnCircleAnnotTool.onStateChange(false, true);
					this.btnPolygonAnnotTool.onStateChange(false, true);
					this.btnArrowAnnotTool.onStateChange(false, true);
					this.btnLineAnnotTool.onStateChange(false, true);
					this.btnPolyLineAnnotTool.onStateChange(false, true);
					this.btnCloudAnnotTool.onStateChange(false, true);
				}
			} else {
				this.btnRectangleAnnotTool.onStateChange(false, false);
				this.btnCircleAnnotTool.onStateChange(false, false);
				this.btnPolygonAnnotTool.onStateChange(false, false);
				this.btnArrowAnnotTool.onStateChange(false, false);
				this.btnLineAnnotTool.onStateChange(false, false);
				this.btnPolyLineAnnotTool.onStateChange(false, false);
				this.btnCloudAnnotTool.onStateChange(false, false);
			}
		},
		/**
		 * Initialize the page zoom lists and zoom function.
		 *
		 */
		_initZoomSelection: function() {
			var zoomList = WebPDF.ViewerInstance.getZoomLevels();
			var liHtml = '',zoomHtmlList = '';
			for (var i = 0; i < zoomList.length; i++) {
				var zoom = zoomList[i];
				if (zoom === WebPDF.ZOOM_FIT_WIDTH || zoom === WebPDF.ZOOM_FIT_PAGE) {
					continue;
				}

				var zoomLevel = zoom * 100 + "%";
				if (zoom == 1)
					liHtml += "<li class='fwr-select-option-li selected'>" + zoomLevel + "</li>";
				else
					liHtml += "<li class='fwr-select-option-li'>" + zoomLevel + "</li>";

				if(i == zoomList.length - 1)
					zoomHtmlList = '<li class="fwr-rb-toolbar-line-split textIndent10"><span>' + zoomLevel + '</span></li>' + zoomHtmlList;
				else
					zoomHtmlList = '<li class="textIndent10"><span>' + zoomLevel + '</span></li>' + zoomHtmlList;
			}

			var zoomDropdownList = $(".fwr-rb-toolbar-zoomlist");
			if(!zoomDropdownList.find('.textIndent10')[0])
				zoomDropdownList.append(zoomHtmlList);

			zoomDropdownList.find('.textIndent10').off('click').click(function() {
				if(!this)
					return;
				var val = parseFloat($(this).text());
				if(!val) {
					return;
				}
				WebPDF.ViewerInstance.zoomTo(val / 100.0);
			});

			liHtml += "<li class='fwr-select-option-li'>" + this.zoomFitPage + "</li>";
			liHtml += "<li class='fwr-select-option-li'>" + this.zoomFitWidth + "</li>";
			var $zoomselectoption = $("#zoomselectoption1");
			$zoomselectoption.html(liHtml);
			$("#zoomSelectInput1").val("100%");

			//Show the page zoom list.
			$("#zoomSelectInput1").off('click').click(function() {
				$("#zoomSelectBox1").show();
				$("#pageSelectBox1").hide();
				$('.fwr-popup-annot-focus').removeClass('fwr-popup-annot-focus');
				return false;
			});

			//When the mouse move out the page jump list hidden the list.
			$("#zoomSelectBox1").mouseleave(function() {
				$(this).hide();
			});

			this.btnZoomOut.onStateChange(true);
			this.btnZoomIn.onStateChange(true);

			var self = this;
			//Click on the page zoom list item then zoom page to the specified proportion.
			var liOption = $zoomselectoption.find('li');
			liOption.off("click").on('click', function() {
				$(this).addClass('selected').siblings().removeClass('selected');
				var value = $(this).text();
				$("#zoomSelectInput1").val(value);
				var val = parseFloat(value);
				if (val) {
					val /= 100;
					WebPDF.ViewerInstance.zoomTo(val);
				} else {
					if (value === self.zoomFitWidth) {
						WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_FIT_WIDTH);
					} else if(value === self.zoomFitPage) {
						WebPDF.ViewerInstance.zoomTo(WebPDF.ZOOM_FIT_PAGE);
					} else {
						WebPDF.ViewerInstance.zoomTo(value);
					}
				}
				$("#zoomSelectBox1").hide();
			});

			//The mouse stay on the page jump list item.
			liOption.hover(function() {
				$(this).addClass('hover').siblings().removeClass('hover');
			}, function() {
				liOption.removeClass('hover');
			});
		},
		_hideRibbonTabs: function(event) {

			if (!$(event.target.parentElement).hasClass('fwr-rb-tab-buttons') &&
				$('.fwr-rb-tabs').hasClass('temp-hide') && $('.fwr-rb-tabs').hasClass('absolute-show')) {
				
				$('.fwr-rb-tabs').removeClass('absolute-show');
				$('.fwr-rb-tab-buttons li:not([data-tab=file])').removeClass('current');
				$('.fwr-rb-tabs>ul>li').removeClass('current');
			}
		},
		//Hide signature and rotation functions list.
		_hideAllList: function() {
			if (this.$stamList.is(":visible"))
				this.$stamList.hide();

			$('#zoomSelectBox1').hide();

			$('.fwr-rb-toolbar-dropdown').hide();
			this.showFuncionlist = false;
		},
		_updateFormToolStatus: function(plugins, docPermission) {
			//support form module
			if (!(plugins & WebPDF.Config.Plugins.flag.Form)) {
				this.btnExportForm.onStateChange(false, true);
				this.btnImportForm.onStateChange(false, true);
				this.inputImportFormXML.onStateChange(false);
			} else {
				if (docPermission.isForm) {
					if (WebPDF.ViewerInstance.hasForm()) {
						this.btnExportForm.onStateChange(true);
						this.btnImportForm.onStateChange(true);
						this.inputImportFormXML.onStateChange(true);
					} else {
						this.btnExportForm.onStateChange(false, true);
						this.btnImportForm.onStateChange(false, true);
						this.inputImportFormXML.onStateChange(false);
					}
					$(window).resize();
				} else {
					this.btnExportForm.onStateChange(false, true);
					this.btnImportForm.onStateChange(false, true);
					this.inputImportFormXML.onStateChange(false);
				}
			}
		},
		//Show or hide tooltip of toolbar
		_changeToolTip: function(obj, isShow) {
			if (isShow) {
				if (!this.showFuncionlist) {
					obj.show();
					resetDropTipPosition(obj);
				}
					
			} else {
				obj.hide();
			}
		},
		_updateSaveStatus: function(plugins, docPermission) {
			//this.btnSave.onStateChange(false, true);
			var isAnnotPermission = plugins & WebPDF.Config.Plugins.flag.Comments && docPermission.isAnnot;
			var isSignPermission = !WebPDF.Engine.isJR && (plugins & WebPDF.Config.Plugins.flag.Signature) && docPermission.isSignature;
			var isFormPermission = plugins & WebPDF.Config.Plugins.flag.Form && docPermission.isForm;

			if (!isAnnotPermission && !isSignPermission && !isFormPermission) {
				$("#btnSave").off("click");
				return;
			}
		},
		/**
		 * change the btton status of page organizer
		 */
		changePPOButtonState : function(enable) {
			this.btnPPORotateLeft.onStateChange(enable,true);
			this.btnPPORotateRight.onStateChange(enable,true);
			this.btnPPODeletePage.onStateChange(enable,true);
		},
		_fullScreen: function() {
			this.mode = WebPDF.ViewerInstance.getViewMode();
			this.bFullScreen = true;
			this.ieFullScreen = true;
			var self = this;
			var fields_highlight_display = false;
			if (!$.support.fullscreen) {
				if (!$(".fwr-modal-scrollable").get(0)) {

					var alertPop = "";
					alertPop += '<div class="fwr-modal-scrollable" style="z-index: 1060;">';
					alertPop += '<div class="fwr-modal-pop fwr-pop-alert">';
					alertPop += '<div class="fwr-pop-header">';
					alertPop += '<h4>' + i18n.t("ModalPop.FullScreen.HeaderTitle") + '</h4>';
					alertPop += '</div>';
					alertPop += '<div class="fwr-pop-body">';
					alertPop += '<p>' + i18n.t("ModalPop.FullScreen.Content") + '</p>';
					alertPop += '</div>';
					alertPop += '<div class="fwr-pop-bottom"><a class="fwr-pop-btn" onclick="javascript:void(0)">' + i18n.t("ModalPop.FullScreen.OKBtnTitle") + '(<em>3</em>)</a></div>';
					alertPop += '</div>';
					alertPop += '<div class="fwr-modal-backdrop fwr-fade fwr-in" style="z-index: 1050;"></div>';
					alertPop += '</div>';
					$("#docViewer").append(alertPop);
					$(".fwrJspContainer-ie").focus();

					var time,
						i = 3;

					$(".fwr-modal-scrollable").find(".fwr-pop-btn").off("click").on("click", function() {
						window.clearInterval(time);
						$(".fwr-modal-scrollable").remove();
					});

					time = window.setInterval(function() {
						i = i - 1;
						if (i < 0) {
							window.clearInterval(time);
							$(".fwr-modal-scrollable").remove();
							$(".fwrJspContainer-ie").focus();
						}
						$(".fwr-modal-scrollable .fwr-pop-btn em").text(i);
					}, 1000);
				}

				$(document).off("keyup").on("keyup", function(event) {
					if (event.keyCode == 122) {
						if (self.ieFullScreen) {
							WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_HAND);
							$("#header").hide();
							$("#toolbar").hide();
							$("#menu").hide();
							$("#left").hide();
							$("#navigation").hide();
							$(".fwr-Nav-panel").hide();
							$("#navigation li").removeClass('fwr-Nav-panel-selected');
							$("#navigation li p").removeClass('selected');

                            var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
                            if(formPlugin) {
                                fields_highlight_display = formPlugin.isHighlightBarVisible();
                                formPlugin.showHighlightBar(false);
                            }
							self.ieFullScreen = false;
							window.setTimeout(function() {
								WebPDF.ViewerInstance.showFullPage();
							}, 50);
							$(window).trigger('resize');

						} else {
							$("#header").show();
							$("#toolbar").show();
							$("#navigation").show();
                            var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
                            if(formPlugin) {
                                formPlugin.showHighlightBar(fields_highlight_display);
                            }
							
							WebPDF.ViewerInstance.setLayoutShowMode(self.mode);
							WebPDF.ViewerInstance.zoomTo(1);
							$(window).trigger('resize');
						}


					} else if (event.keyCode == 27) {
						WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_HAND);
						WebPDF.ViewerInstance.zoomTo(1);
						$(window).trigger('resize');
					}
				});
				return;
			}
			var jqViewContainer = $("#docViewer");
			WebPDF.ViewerInstance.setCurrentToolByName(WebPDF.Tools.TOOL_NAME_HAND);

			$("#header").hide();
			$("#toolbar").hide();
			$("#menu").hide();
			$("#left").hide();
			$("#navigation").hide();
			$("#navigationPanel").hide();
			$('#navigation li').removeClass('fwr-Nav-panel-selected');
			$('#navigation li>p').removeClass('selected');

            var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
            if(formPlugin) {
                fields_highlight_display = formPlugin.isHighlightBarVisible();
                formPlugin.showHighlightBar(false);
            }

			$(window).trigger('resize');

			jqViewContainer.fullScreen({
				'callback': function(isFullScreen) {
					if (!isFullScreen) {
						//$("#header").show();
						$("#navigation").show();
						$("#toolbar").show();
                        var formPlugin = WebPDF.ViewerInstance.getPluginByName(WebPDF.FormPluginName);
                        if(formPlugin) {
                            formPlugin.showHighlightBar(fields_highlight_display);
                        }
						self.bFullScreen = false;
						
						WebPDF.ViewerInstance.setLayoutShowMode(self.mode);
						WebPDF.ViewerInstance.zoomTo(1);
						$(window).trigger('resize');
					} else {
						var timer = WebPDF.Environment.ieAtLeast11 === true ? 300 : 50;
						window.setTimeout(function() {
							WebPDF.ViewerInstance.showFullPage();
						}, timer);
						$(window).trigger('resize');
						WebPDF.ViewerInstance.focus();
					}
				}
			});
		}
	};

	function resetDropPosition($obj) {
		if ($obj.parents('.fwr-more-tools').size() > 0) {
			var width = $obj.outerWidth();
			$obj.children('li').width(width - 10);
			var right = $('.fwr-more-tools').outerWidth();
			$obj.css({
				'top':0,
				'right': right,
				'width': width,
				'left': 'none'
			});
		} else {
			$obj.css({
				'top':'30px',
				'right':'auto',
				'width': 'auto'
			});
		}
	}


	function resetDropTipPosition($obj){
		var objWidth = $obj.outerWidth();
		var offsetX = $obj.offset().left + objWidth;
		var windowWidth = $(window).width();
		var sub = windowWidth - offsetX;
		if (sub < 0) {
			$obj.css('left', parseInt($obj.css('left')) + sub - 5);
		}
	} 

	function changeBtnUI(id, uiOption) {
		var $ele = $('#' + id);
		$ele.data('id', uiOption.id);
		$ele.addClass('selected');
		
		$ele.children('i').attr('class', uiOption.className);
		$ele.children().children('i').attr('class', uiOption.className);
		
		$ele.data('tipdesc', uiOption.tipdesc);
		$ele.data('tiptit', uiOption.tiptit);
	}

	function changeTargetUI(currentBtnObj, currentBtnEle, targetBtnObj,isDisableSelect) {
		var className = $(currentBtnEle).children('i')[0].className;
		if(!isDisableSelect){
			className = className;
		}
		var text = '';
		var tiptit = $(currentBtnEle).data('tiptit');
		var tipdesc = $(currentBtnEle).data('tipdesc');
		var uiOption = {
			id: currentBtnObj.id,
			className: className,
			text: text,
			tiptit: tiptit,
			tipdesc: tipdesc
		};
		targetBtnObj.onStateChange(true, true, uiOption);
	}

	function commonSelectStatusChange(id, selected) {
		var $element = $('#' + id);
		if (selected) {
			$element.addClass('selected');
		} else {
			$element.removeClass('selected');
		}
	}

	function commonStatusChange1(obj, enable) {
		var $btnElement = $('#' + obj.id);
		if (enable) {
			$btnElement.removeClass('fwr-select-disabled');
			obj.onClick();
		} else {
			$btnElement.addClass('fwr-select-disabled');
			$btnElement.off('click')
		}
	}

	function commonStatusChange(obj, enable, visible, isDropList) {
		if (enable == true) {
				visible = true;
		}
		var $btnElement = $('#' + obj.id);
		if ($btnElement.length == 0)
			return;
		if (visible) {
			if (enable) {
				$btnElement.removeClass("disabled");
				obj.onClick();
				if (!isDropList) {
					$btnElement.parent().show();
				}
			} else {
				$btnElement.addClass("disabled");
				$btnElement.off('click');
			}
		} else {
			$btnElement.off('click');
			$btnElement.addClass('disabled');
		}
	}

	function commonStatusListChange(obj, enable, visible) {
		if (enable) {
			visible = true;
		}
		var $id = $('#' + obj.id);
		if (visible) {
			if (enable) {
				$id.removeClass("disabled");
				$id.siblings('.btn-dropdown').removeClass("disabled");
				$id.children('.btn-dropdown').removeClass("disabled");
				obj.onClick();
			} else {
				$id.addClass("disabled");
				$id.siblings('.btn-dropdown').addClass("disabled");
				$id.children('.btn-dropdown').addClass("disabled");
				$id.off("click");
			}
			$id.parent().show();
		} else {
			$id.addClass("disabled");
			$id.off("click");
			$id.parent().hide();
		}
	}

	/**
	 * Initialize the page jump lists and jump function.
	 *
	 */
	function initGotoPageSelection() {

		var $pageSelectBox = $("#pageSelectBox");
		var $pageSelectOption = $("#pageSelectOption");
		$pageSelectOption.html('');

		var pageCnt = WebPDF.ViewerInstance.getPageCount();
		for (var i = 0; i < pageCnt; i++) {
			var liHtml = "<li class='fwr-select-option-li' style=''>" + (i + 1) + " / " + pageCnt + "</li>";
			$pageSelectOption.append(liHtml);
		}

		var $pageSelectInput = $("#pageSelectInput");
		//var $pageSelectBar = $("#pageSelectBar");
		var lastInputValue = null;
		$pageSelectInput.val(1 + " / " + pageCnt);

		//Loose foucs
		$('#pageSelectInput').blur(function(){
			if (lastInputValue) {
				$(this).val(lastInputValue);
				lastInputValue = null;
			} else {
				var pageIndex = WebPDF.ViewerInstance.getCurPageIndex() + 1;
				$(this).val(pageIndex + " / " + pageCnt);
			}
		});

		//When the mouse move out the page jump list hidden the list.
		$pageSelectBox.mouseleave(function() {
			$(this).hide();
		});

		//Click on the page jump list item then jump to the specified page.
		var liOption = $pageSelectOption.find('li');
		liOption.off("click").on('click', function() {
			$(this).addClass('selected').siblings().removeClass('selected');
			var value = $(this).text();
			$pageSelectInput.val(value);
			var pages = value.split("/");
			WebPDF.ViewerInstance.gotoPage(parseInt(pages[0]) - 1);
			$pageSelectBox.hide();
		});
		$pageSelectInput.off('click').click(function(event) {
			$pageSelectBox.show();
			lastInputValue = $(this).val();
			$(this).val("");
		});

		$pageSelectInput.off('keyup').keyup(function(event) {
			if (event.keyCode === 13) {
				var self = this;
				var val = $(self).val();
				var pages = val.split('/');
				var page = $.trim(pages[0]);
				if (!$.isNumeric(page)) {
					$(this).val((WebPDF.ViewerInstance.getCurPageIndex() + 1) + " / " + (WebPDF.ViewerInstance.getPageCount()));
				} else if(page > pageCnt || page < 1 ) {
					var beyondPage = i18n.t('PageSelect.MaxPageTip');
					beyondPage = beyondPage.replace("{}",'"' + val + '"');
					WebPDF.alert(null, null, beyondPage, i18n.t('PageSelect.CloseBtn'), function(){
						var curPageIndex = WebPDF.ViewerInstance.getCurPageIndex();
						$(self).val((curPageIndex + 1) + ' / ' + pageCnt);
					});
				}
				else {
					WebPDF.ViewerInstance.gotoPage(page - 1);
					$(self).val(page + ' / ' + pageCnt);
					lastInputValue = value;
				}
				$pageSelectBox.hide();
			}else{
				var value = $(this).val().split("/")[0].replace(/[^\d]/g,'');
				var newValue = value.toString();
				if (newValue == 0 && newValue.length > 1) {
					$(this).val(0);
					return;
				}
				$(this).val(value);
			}
		   
		})

		//The mouse stay on the page jump list item.
		liOption.hover(function() {
			$(this).addClass('hover').siblings().removeClass('hover');
		}, function() {
			liOption.removeClass('hover');
		});
	}

	//for import form xml, judge the file name is valid or not
	function _isXmlNameValid(fileName) {
		return typeof fileName != 'undefined' && /[^/\.]\.xml\s*$/.test(fileName.toLowerCase());
	}

	var _openDlgID = "internetDlg";

	function _createOnlineUrlDlgHtml(option) {
		var dlgHtml = "<div id='{dlgID}' class='fwr-print-dlg fwr-modal fwr-hide fwr-fade fwr-in ' style='display: none; z-index: 1004; outline: 0px; position: absolute; height: auto; width: 350px;'>" +
			//header
			"<div class='fwr-modal-header' >" +
			"<a class='close' webpdf-data-dismiss='modal'></a>" +
			"<h4 >{title}</h4>" +
			"</div>" +
			//body
			"<div id='content'  class='fwr-modal-body fwr-dialog-padding ui-dialog-content ui-widget-content'>" +
			"<div>{tip}</div>" +
			"<input type='text' id='{inputId}' style='width:100%;margin-top:20px;background: white;height: 29px;border: 1px #C0C0C0 solid;' >" +
			"</div>" +
			//footer
			"<div class='fwr-modal-footer'>" +
			"<a href='#' id='{okId}' class='btn btn-success' >{okTitle}</a>" +
			"<a href='#' id='{cancelId}' class='btn' webpdf-data-dismiss='modal'>{cancelTitle}</a>" +
			"</div>" +
			"</div>";
		return dlgHtml.format(option);
	}

	function _showOpenOnlineUrlDialog() {
		var option = {
			dlgID: _openDlgID,
			title: i18n.t("CommonLng.Create.OnlineFileDlgTitle"),
			tip: i18n.t("CommonLng.Create.OnlineUrl"),
			okId: "btnOkOpen",
			okTitle: i18n.t("CommonDialog.DefaultOKBtnTitle"),
			inputId: "onlineUrlInput",
			cancelId: "btnCancelOpen",
			cancelTitle: i18n.t("CommonDialog.DefaultCancelBtnTitle")
		};

		if ($("#" + _openDlgID).length == 0) {
			var _dlgHtml = _createOnlineUrlDlgHtml(option);
			$('#' + docViewerId).append(_dlgHtml);

			$("#" + option.okId).on("click", function() {
				var fileUrl = encodeFileNameByUrl($("#" + option.inputId).val());
				if (!_checkFileNameValid(fileUrl)) {
					return false;
				}
				_hideOpenOnlineUrlDialog();
				var params = {
					url: fileUrl
				};
				WebPDF.ViewerInstance.openFileByUri(params);
				return false;
			});
		}

		$("#" + _openDlgID).webPDFModal({
			keyboard: false,
			backdrop: "static",
			manager: "#docViewer"
		});

		$("#" + option.inputId).focus();
	}
	/*
	 *hidden signature progress dialog
	 *
	 */
	function _hideOpenOnlineUrlDialog() {
		$("#" + _openDlgID).webPDFModal("hide");
	}

	function _initSeniorFeature() {
		$('.fwr-rb-tabs li[data-label=protect-redaction]').removeClass('hide');
		var $protectpassword = $('.fwr-rb-tabs li[data-label=protect-password]').addClass('hide');
		$protectpassword.removeClass('hide');
	}

	function _createDocProperties() {
		var docProperties = WebPDF.Tool.getReaderApp().getPDFDoc().getDocProperties();
		var fileName = WebPDF.Tool.getReaderApp().getFileName();
		var pageCount = WebPDF.Tool.getReaderApp().getMainView().getDocView().getPageCount();
        if (!docProperties) {
            return;
        }
		var html = '';
		html += '<h4><i class="fwr-rb-icons-32 fwr-rb-file-description"></i> <span data-i18n="[html]DocProperties.Description">Description</span></h4>';
		html += '<h5 class="mt10" data-i18n="[html]DocProperties.General">General</h5>';
		html += '<table class="fwr-rb-file-table2 mt10">';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.FilenName">File</td>';
		html += '		<td>' + (fileName == null? '': fileName) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.PDFVersion">PDF Version</td>';
		html += '		<td>' + (docProperties.getVersion() == null? '': docProperties.getVersion()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.PageSize">Page Size</td>';
		html += '		<td id="docPropertiesPageSize">' + (_getPageSize() == null? '': _getPageSize()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.NumOfPages">Pages</td>';
		html += '		<td>' + (pageCount == null? '': pageCount) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.PDFTitle">Title</td>';
		html += '		<td metadata-key="title">' + (docProperties.getTitle() == null? '': docProperties.getTitle()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.Subject">Subject</td>';
		html += '		<td metadata-key="subject">' + (docProperties.getSubject() == null? '': docProperties.getSubject()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.Creator">Creator</td>';
		html += '		<td metadata-key="creator">' + (docProperties.getCreator() == null? '': docProperties.getCreator()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.Author">Author</td>';
		html += '		<td metadata-key="author">' + (docProperties.getAuthor() == null? '': docProperties.getAuthor()) +'</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.Producer">Producer</td>';
		html += '		<td metadata-key="producer">' + (docProperties.getProducer() == null? '': docProperties.getProducer()) + '</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.Keywords">Keywords</td>';
		html += '		<td metadata-key="keywords">' + (docProperties.getKeywords() == null? '': docProperties.getKeywords()) + '</td>';
		html += '	</tr>';
		html += '</table>';
		html += '<h5 class="mt10" data-i18n="[html]DocProperties.RelatedDates">Related Dates</h5>';
		html += '<table class="fwr-rb-file-table2 mt10">';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.ModifyDate">Last Modified</td>';
		html += '		<td metadata-key="moddate">' + (docProperties.getModifyDate() == null? '': docProperties.getModifyDate()) +'</td>';
		html += '	</tr>';
		html += '	<tr>';
		html += '		<td data-i18n="[html]DocProperties.CreateDate">Created</td>';
		html += '		<td metadata-key="creationdate">' + (docProperties.getCreationDate() == null? '': docProperties.getCreationDate()) + '</td>';
		html += '	</tr>';
		html += '</table>';

		$('#docProperties').html('').append(html).i18n();
	}

	function _getPageSize() {
		var curPageIndex = WebPDF.Tool.getReaderApp().getMainView().getDocView().getCurPageIndex();
		var pdfPage = WebPDF.Tool.getReaderApp().getPDFDoc().getPage(curPageIndex);
		var unit = 'cm';
		var w = _convertValueFromPointUnit(unit, pdfPage.getPageWidth());
		var h = _convertValueFromPointUnit(unit, pdfPage.getPageHeight());

		return '['+ w +' * ' + h +' cm]';
	}

	function _convertValueFromPointUnit(targetUnit, value) {
        var ptValue = WebPDF.Common.changeUnit(value, "point", targetUnit);
        return WebPDF.Common.parseValueToDecimal(ptValue, 2);
    }

    function _addRbTitle(){
    	var filename = WebPDF.Tool.getReaderApp().getFileName();
    	var index = filename.lastIndexOf('.');
    	if (index > 0) {
    		filename = filename.substr(0, index);
    	}
    	if (filename == null || filename === '') {
    		return;
    	}
    	var rightbarWidth = $('.fwr-rb-rightbar').outerWidth() + 50;
    	var $rbtitle = $('.fwr-rb-title');
    	$rbtitle.addClass('suffix')
    	.css({
    		'paddingRight': rightbarWidth
    	}).html('<em>' + filename + '</em>');

    	var emwidth = $('.fwr-rb-title>em').width();
    	if (emwidth > $rbtitle.width()) {
    		rightbarWidth += 26;
    		$rbtitle.css('paddingRight', rightbarWidth);
    		rightbarWidth -= 26;
    		$rbtitle.find('style').remove();
    		$rbtitle.append('<style>.fwr-rb-title.suffix::after{right:'+ rightbarWidth +'px;}</style>');
    	}
    }

    //*************fiel open***************/
	function _initFileOpenProc() {
		var $fileUploadForm = $("#fileUploadForm");
		var $filePath = $("#path");
		
		var $fdfUploadForm = $("#fdfFileUploadForm");
		var $fdfFilePath = $("#fdfPath");
		
		var $xfdfUploadForm = $("#xfdfFileUploadForm");
		var $xfdfFilePath = $("#xfdfPath");
		
		$filePath.change(function(e) {			
			$curFileUploadForm = $fileUploadForm;
			$curFilePath = $filePath;
			
			var res = _onFilePathChangeEvent(e);		
			
			$('.fwr-rb-tab-buttons>li').removeClass('current');
			$('.fwr-rb-tab-file').hide();
			$('.fwr-rb-tab-buttons>li[data-tab=home]').click();
			if(res){
				$('#openFileInView').hide();
			}
		});
		
		$fdfFilePath.change(function(e) {
			$curFileUploadForm = $fdfUploadForm;
			$curFilePath = $fdfFilePath;
			var file = e.target.files ? e.target.files[0] : null;
			if (!file && e.dataTransfer && e.dataTransfer.files.length > 0) {
				file = e.dataTransfer.files[0];
			}
			if (!file) {
				return;
			}
			
			fpFileProc.importFDFFile(file);
			resetFormElement($curFilePath);
		});
		
		if(!(WebPDF.Environment.ie8OrLower || WebPDF.Environment.ie9Compact)) {	
			$xfdfFilePath.on ('change',function(e) {
				if (WebPDF.Environment.ie8OrLower || WebPDF.Environment.ie9Compact) {
					WebPDF.alert(null, null, i18n.t("Compatible.IE9orLower"));
					return;
				}
				$curFileUploadForm = $xfdfUploadForm;
				$curFilePath = $xfdfFilePath;
				
				var file = e.target.files ? e.target.files[0] : null;
				if (!file && e.dataTransfer && e.dataTransfer.files.length > 0) {
					file = e.dataTransfer.files[0];
				}					
				if (!file) {
					return;
				}

				if(file.type.indexOf("xfdf") == -1){
					WebPDF.alert(null,null,i18n.t("PCLng.ToolBar.ImportFile.XFDFTypeError"));
					return;
				}

				fpFileProc.ImportXFDFFileToPDF(file);
				resetFormElement($xfdfFilePath);
			});
		}else{
			$xfdfFilePath.remove();
		}
		
		$("#btnImportForm").off('change').on('change', function(event) {
			if (event.target.files.length == 0)
				return;
			var fileName = event.target.files[0].name;
			if (fileName == undefined || fileName == "")
				return false;
			if (!fileName || !/.*\.xml\s*$/.test(fileName.toLowerCase())) {
				WebPDF.alert(null, null, i18n.t("Form.XMLError"));
				return;
			}
			$curFilePath = $("#inputImportFormXML");
			
			var files = event.target.files;			
			fpFileProc.importFormXML(files[0]);			
			resetFormElement($curFilePath);
		});
		
		function _onFilePathChangeEvent(e) { 
			var file = e.target.files ? e.target.files[0] : null;
			if (!file && e.dataTransfer && e.dataTransfer.files.length > 0) {
				file = e.dataTransfer.files[0];
			}
			
			if (!file) {
				// to be done
				$curFileUploadForm[0].reset();
				return false;
			}
			
			if(file.type !== 'application/pdf'){
				WebPDF.alert(null, null, i18n.t("document.invalid"));
				$curFileUploadForm[0].reset();
				return false;
			}
			
			var fileFullPath = $curFilePath.val();
			
			/*if (confirmSaveIfDocModified(callback)) {
				return true;
			}*/
			
			WebPDF.Tool.getReaderApp().setObjectId("");
			WebPDF.Tool.getReaderApp().setViewMode(0);
			
			fpFileProc.openFile(file, fileFullPath);
			
			resetFormElement($curFilePath);
			return true;
		}
		
		function resetFormElement(e) {
			e.wrap('<form>').closest('form').get(0).reset();
			e.unwrap();
		}
		
		fpFileProc.openFileByUri();
	}
	function canUse(ele) {
		var canNotUse = $(ele).hasClass("no-use-pdfeditor") || $(ele).parents(".no-use-pdfeditor").length;
		return !canNotUse;
	}
	var viewToolBar;

	//obj
	var obj = {
		getViewToolBar: function(options) {
			if(viewToolBar == null) {
				viewToolBar = new ViewToolBar(options);
			}
			return viewToolBar;
		}
	};
	return obj;
})();