/**
 * Copyright(C) 2015-2016, Foxit Software Inc..
 * All Rights Reserved.
 *
 * http//:www.foxitsoftware.com
 *
 * The following code is copyrighted and contains proprietary information and trade secrets of Foxit Software Inc..
 * You cannot distribute any part of Foxit WebPDF Viewer to any third party or general public,
 * unless there is a separate license agreement with Foxit Software Inc. which explicitly grants you such rights.
 *
 */
(function(global) {

    /**
     * Function defined to get current browser language and user setting language.
     *
     * @returns {string} The current browser language.
     */
    global.getBrowserLanguage = function getBrowserLanguage() {
        return navigator.language || navigator.userLanguage;
    };

    /**
     * Function defined to get current language.
     *
     * @returns {string} The current language.
     */
    global.getLanguage = function getLanguage() {
        var language = global.getUrlParam("al");
        if (!language) {
            language = global.getBrowserLanguage();
        }
        if (language && language.toLowerCase() != "zh-cn") {
            language = "en-US";
        } else {
            language = "zh-CN";
        }
        return language;
    };

    /**
     * Function defined to get current doc uri from the browser URL.
     *
     * @returns {string} The doc uri.
     */
    var docUri = null;

    global.getDocUri = function getDocUri() {
        if (docUri) {
            return docUri;
        }
        //first, get docuri from url
        docUri = global.getUrlParam("docuri");
        if (docUri == null) {
            return docUri;
        }
        docUri = global.encodeFileNameByUrl(docUri);
        return docUri;
    };


    global.getViewMode = function getViewMode() {
        var vieweMode = global.getUrlParam("viewermodel");
        if (!vieweMode) {
            vieweMode = 0;
        } else {
            vieweMode = parseInt(vieweMode);
        }
        return vieweMode;
    }

    global.getObjectId = function getObjectId() {

        var objectid = global.getUrlParam("object_id");
        if (!objectid) {
            //if not, get docuri from cookie
            var cookieDocUri = global.getCookie("object_id");
            objectid = "";
            if (cookieDocUri) {
                objectid = cookieDocUri;
            }
            global.delCookie("object_id", "/");
        }
        return objectid;
    };

    global.getAccount = function getAccount() {
        var account = global.getUrlParam("account");
        if (!account) {
            //if not, get account from cookie
            var cookieAccount = global.getCookie("account");
            account = "";
            if (cookieAccount) {
                account = cookieAccount;
            }
            global.delCookie("account", "/");
        }
        return account;
    };

    global.getParamString = function getParamString(url) {
        var index = url.indexOf("?");
        var newParamString = "";
        if (index != -1) {
            newParamString = "?"
            var str = url.substr(index + 1);
            var strs = str.split("&");
            for (var i = 0; i < strs.length; i++) {
                newParamString += strs[i].split("=")[0] + "=" + global.encodeURL(strs[i].split("=")[1]);
                if (i != strs.length - 1) {
                    newParamString += "&";
                }
            }
        }
        return newParamString;
    };


    global.encodeFileNameByUrl = function encodeFileNameByUrl(fileUrl) {
        var paramString = "";
        var baseUrl = fileUrl;
        var i = fileUrl.lastIndexOf('?');
        if (i > -1) {
            baseUrl = fileUrl.substr(0, i);
            paramString = global.getParamString(fileUrl);
        }
        i = baseUrl.lastIndexOf('/');
        var hostUrl = baseUrl.substr(0, i + 1);
        var lastPathUrl = baseUrl.substr(i + 1);
        fileUrl = encodeURI(hostUrl) + global.encodeURL(lastPathUrl) + paramString;
        return fileUrl;
    };

    global.encodeURL = function encodeURL(str) {

        var fileName = "";
        str = str.replace(/\%(?![0-9a-fA-F]{2})/g, "%25");
        try {
            fileName = decodeURIComponent(str);
        } catch (e) {
            try {
                fileName = decodeURIComponent(unescape(str));
            } catch (e) {
                fileName = str;
            }

        }
        return encodeURIComponent(fileName);
    };
    /**
     * Function defined to get base url.
     *
     * @returns {string} The base url of current domain.
     */
    global.getBaseUrl = function getBaseUrl() {
        return location.protocol + '//' + location.host + location.pathname.split('/').slice(0,-1).join('/') + '/';
    };

    /**
     * Check whether browser support cookie.
     *
     * @returns {boolean} True if current browser enable cookie, false for else.
     */
    global.isEnableCookie = function isEnableCookie() {
        return window.navigator.cookieEnabled ? true : false;
    };

    /**
     * Function defined to set browser cookie.
     *
     * @param {string} c_name The cookie name..
     * @param {string} value The cookie value..
     * @param {string} path The cookie path scope.
     * @param {string} expireHours The cookie expire time.
     */
    global.setCookie = function setCookie(c_name, value, path, expireHours) {
        var exdate = new Date();
        exdate.setHours(exdate.getHours() + expireHours);

        var cookie = c_name + "=" + escape(value);
        if (path) {
            cookie += ";path=" + path;
        }
        if (expireHours) {
            cookie += ";expires=" + exdate.toGMTString();
        }
        document.cookie = cookie;
    };


    /**
     * Function defined to get a cookie value.
     * 
     * @param {string} key The cookie name.
     * 
     * @returns {string} The cookie value.
     */
    global.getCookie = function getCookie(key) {
        var arr, reg = new RegExp("(^| )" + key + "=([^;]*)(;|$)");

        if (arr = document.cookie.match(reg)) {
            return unescape(arr[2]).replace(/\"/g, "");
        } else
            return null;
    };

    /**
     * Function defined to delete a cookie .
     * 
     * @param {string} name The cookie name..
     */
    global.delCookie = function delCookie(name, path) {
        global.setCookie(name, "", path, -1);
    };

    /**
     * Check whether current string value could be parsed as JSON object.
     *
     * @param {string} str The string value.
     *
     * @returns {boolean} True if the string is formatted as a JSON form, false for else.
     */
    global.isCanToJson = function isCanToJson(str) {
        try {
            if (str && str != "null" && str != "") {
                JSON.parse(str);
                return true;
            }
            return false;
        } catch (e) {
            return false;
        }
    };

    /**
     * Function defined to check whether the passed object is a json object.
     * 
     * @param {object} obj The json object.
     * 
     * @returns {boolean} True if the object is a JSON object, false for else.
     */
    global.isJson = function isJson(obj) {
        var isjson = typeof(obj) == "object" && Object.prototype.toString.call(obj).toLowerCase() == "[object object]" && !obj.length;
        return isjson;
    };

    /**
     * Function defined to get url parameter value.
     *
     * @param {string} name The parameter name.
     * @param {string} url The specified URL value.
     *
     * @returns {object} The parameter value.
     */
    global.getUrlParam = function getUrlParam(name, url) {
        var reg = new RegExp("(^|&)" + name + "=([^&]*)(&|$)");
        var r;
        if (url) {
            r = url.search.substr(1).match(reg);
        } else {
            r = window.location.search.substr(1).match(reg);
        }
        if (r != null) return decodeURIComponent(r[2]);
        return null;
    };

    /**
     * Function defined to bind resize event.
     *
     * @param el
     * @param obj
     */
    global.bindResize = function bindResize(el, obj) {
        var els = obj[0].style;
        var Y = 0;
        $(el).mousedown(function(e) {
            Y = e.clientY - el.offsetHeight - obj.height();
            el.setCapture ? (el.setCapture(), el.onmousemove = function(ev) {
                mouseMove(ev || event);
            }, el.onmouseup = mouseUp) : ($(document).bind("mousemove", mouseMove).bind("mouseup", mouseUp));
            e.preventDefault();
        });

        function mouseMove(e) {
            els.height = e.clientY - Y + 'px';
        }

        function mouseUp() {
            el.releaseCapture ? (el.releaseCapture(), el.onmousemove = el.onmouseup = null) : ($(document).unbind("mousemove", mouseMove).unbind("mouseup", mouseUp));
        }
    };

    /**
     * Function defined to prevent default event propagation.
     */
    global.preventDefaults = function preventDefaults(event) {
        if (event && event.stopPropagation) {
            event.stopPropagation();
        } else {
            window.event.cancelBubble = true;
        }
        if (event && event.preventDefault) {
            event.preventDefault();
        } else {
            window.event.returnValue = false;
        }
    };

    /**
     * Check the validate of email.
     *
     * @param {stringa} email The input email.
     *
     * @returns {boolean} True if the email is valid, false for else.
     */
    global.checkEmail = function checkEmail(email) {
        if (typeof email === undefined || email.length < 1) {
            return false;
        }

        var reg = /\w+[@]{1}\w+[.]\w+/;
        if (!reg.test(email)) {
            return false;
        }

        return true;
    };

    global.getFileName = function getFileName(fullPath) {
        var path = fullPath;

        var x = path.lastIndexOf('/');
        if (x >= 0) // Unix-based path
            return path.substr(x + 1);
        x = path.lastIndexOf('\\');
        if (x >= 0) // Windows-based path
            return path.substr(x + 1);
        return path;
    };

    global.isIE = function isIE() {
        var agent = navigator.userAgent.toLowerCase();
        var opera = window.opera;
        var isIE = /msie/.test(agent) && !/opera/.test(agent) && document.all || (!/msie/.test(agent) && /trident/.test(agent) && !/opera/.test(agent));
        return isIE || /win/.test(agent);
    };
    /**
     * Function defined to check whether is a mobile device.
     *
     * @returns {boolean|*} True if current client is a mobile device, false for else.
     */
    global.isMobile = function isMobile() {
        var agent = navigator.userAgent.toLowerCase();
        var opera = window.opera;

        var env = {
            /**
             *  iPhone/iPad/iPod
             */
            iOS: /(ipad|iphone|ipod)/.test(agent),
            android: /android/i.test(agent),
            blackberry: /blackberry/i.test(agent),
            webos: /webos/i.test(agent),
            kindle: /silk|kindle/i.test(agent),
            /**
             HTTPS
             */
            secure: location.protocol == 'https:'
        };

        env.mobile = /mobile/i.test(agent) || env.iOS || env.android || env.blackberry || env.webos || env.kindle;
        return env.mobile;
    };

    global._isFileNameValid = function _isFileNameValid(fileName, isOnline) {
        if (isOnline)
            return typeof fileName != 'undefined'
        else
            return typeof fileName != 'undefined' && /[^/]\.pdf\s*$/.test(fileName.toLowerCase());
    };

    global._checkFileNameValid = function _checkFileNameValid(fileUrl, isOnline) {
        if (!global._isFileNameValid(fileUrl, isOnline)) {
            WebPDF.alert(null, null, i18n.t("CommonLng.Create.NotFound"));
            return false;
        }
        WebPDF.Tool.readerApp.fileUrl = fileUrl;
        return true;
    };

    global.resetDropTipPosition = function resetDropTipPosition($obj) {
        if (!$obj) {
            return false;
        }
        var wWidth = $(window).width();
        var offsetLeft = $obj.offset().left;
        var width = $obj.width();
        var left = (offsetLeft + width - wWidth);
        if (left > 0) {
            left = '-' + left + 'px';
            $obj.css({
                left: left
            });
        }
    };
})(window);